@@ -484,27 +484,27 @@ dir_list_filter_and_sort (GList    *dir_list,
 			  gboolean  show_dot_files)
 {
 	GList *filtered;
-        GList *scan;
+	GList *scan;
 
-        /* Apply filters on dir list. */
-        filtered = NULL;
-        scan = dir_list;
-        while (scan) {
-                const char *name_only = file_name_from_path (scan->data);
+	/* Apply filters on dir list. */
+	filtered = NULL;
+	scan = dir_list;
+	while (scan) {
+		const char *name_only = file_name_from_path (scan->data);
 
-                if (! (file_is_hidden (name_only) && ! show_dot_files)
-                    && (strcmp (name_only, CACHE_DIR) != 0)) {
-                        char *s;
-                        char *path = (char*) scan->data;
+		if (! (file_is_hidden (name_only) && ! show_dot_files)
+		    && (strcmp (name_only, CACHE_DIR) != 0)) {
+			char *s;
+			char *path = (char*) scan->data;
 
-                        s = g_strdup (names_only ? name_only : path);
-                        filtered = g_list_prepend (filtered, s);
-                }
-                scan = scan->next;
-        }
-        filtered = g_list_sort (filtered, (GCompareFunc) strcasecmp);
+			s = g_strdup (names_only ? name_only : path);
+			filtered = g_list_prepend (filtered, s);
+		}
+		scan = scan->next;
+	}
+	filtered = g_list_sort (filtered, (GCompareFunc) strcasecmp);
 
-        return filtered;
+	return filtered;
 }
 
 
@@ -517,46 +517,46 @@ visit_rc_directory_sync (const char *rc_dir,
 			 gpointer    data)
 {
 	char  *rc_dir_full_path;
-        GList *files, *dirs;
-        GList *scan;
-        int    prefix_len, ext_len;
-        char  *prefix;
+	GList *files, *dirs;
+	GList *scan;
+	int    prefix_len, ext_len;
+	char  *prefix;
 
-        prefix = g_strconcat ("file://",
+	prefix = g_strconcat ("file://",
 			      g_get_home_dir(),
-                              "/",
-                              rc_dir,
-                              NULL);
-        prefix_len = strlen (prefix);
-        rc_dir_full_path = g_strconcat (prefix,
-                                        dir,
-                                        NULL);
-        g_free (prefix);
-        ext_len = strlen (rc_ext);
+			      "/",
+			      rc_dir,
+			      NULL);
+	prefix_len = strlen (prefix);
+	rc_dir_full_path = g_strconcat (prefix,
+					dir,
+					NULL);
+	g_free (prefix);
+	ext_len = strlen (rc_ext);
 
-        if (! path_is_dir (rc_dir_full_path)) {
-                g_free (rc_dir_full_path);
-                return FALSE;
-        }
+	if (! path_is_dir (rc_dir_full_path)) {
+		g_free (rc_dir_full_path);
+		return FALSE;
+	}
 
-        path_list_new (rc_dir_full_path, &files, &dirs);
+	path_list_new (rc_dir_full_path, &files, &dirs);
 
 	for (scan = files; scan; scan = scan->next) {
-                char *rc_file, *real_file;
+		char *rc_file, *real_file;
 
-                rc_file = (char*) scan->data;
-                real_file = g_strndup (rc_file + prefix_len,
-                                       strlen (rc_file) - prefix_len - ext_len);
-                if (do_something)
+		rc_file = (char*) scan->data;
+		real_file = g_strndup (rc_file + prefix_len,
+				       strlen (rc_file) - prefix_len - ext_len);
+		if (do_something)
 			(*do_something) (real_file, rc_file, data);
 
-                g_free (real_file);
-        }
+		g_free (real_file);
+	}
 
-        if (! recursive)
-                return TRUE;
+	if (! recursive)
+		return TRUE;
 
-        for (scan = dirs; scan; scan = scan->next) {
+	for (scan = dirs; scan; scan = scan->next) {
 		char *sub_dir = (gchar*) scan->data;
 
 		visit_rc_directory_sync (rc_dir,
@@ -567,7 +567,7 @@ visit_rc_directory_sync (const char *rc_dir,
 					 data);
 	}
 
-        return TRUE;
+	return TRUE;
 }
 
 
@@ -630,7 +630,7 @@ gboolean mime_type_is_image (const char *mime_type)
 
 
 gboolean file_is_image (const gchar *name,
-	                gboolean     fast_file_type)
+			gboolean     fast_file_type)
 {
 	const char *mime_type = NULL;
 
@@ -649,47 +649,47 @@ gboolean mime_type_is_video (const char *mime_type)
 
 
 gboolean file_is_video (const gchar *name,
-                        gboolean     fast_file_type)
+			gboolean     fast_file_type)
 {
-        const char *mime_type = NULL;
+	const char *mime_type = NULL;
 
-        mime_type = get_file_mime_type (name, fast_file_type);
-        if (mime_type == NULL)
-                return FALSE;
+	mime_type = get_file_mime_type (name, fast_file_type);
+	if (mime_type == NULL)
+		return FALSE;
 
-        return mime_type_is_video (mime_type);
+	return mime_type_is_video (mime_type);
 }
 
 
 gboolean mime_type_is_audio (const char *mime_type)
 {
-        return (strstr (mime_type, "audio") != NULL);
+	return (strstr (mime_type, "audio") != NULL);
 }
 
 
 gboolean file_is_audio (const gchar *name,
-                        gboolean     fast_file_type)
+			gboolean     fast_file_type)
 {
-        const char *mime_type = NULL;
+	const char *mime_type = NULL;
 
-        mime_type = get_file_mime_type (name, fast_file_type);
-        if (mime_type == NULL)
-                return FALSE;
+	mime_type = get_file_mime_type (name, fast_file_type);
+	if (mime_type == NULL)
+		return FALSE;
 
-        return mime_type_is_audio (mime_type);
+	return mime_type_is_audio (mime_type);
 }
 
 
 gboolean file_is_image_video_or_audio (const gchar *name,
-                                 gboolean     fast_file_type)
+				 gboolean     fast_file_type)
 {
-        const char *mime_type = NULL;
+	const char *mime_type = NULL;
 
-        mime_type = get_file_mime_type (name, fast_file_type);
-        if (mime_type == NULL)
-                return FALSE;
+	mime_type = get_file_mime_type (name, fast_file_type);
+	if (mime_type == NULL)
+		return FALSE;
 
-        return mime_type_is_image (mime_type) ||
+	return mime_type_is_image (mime_type) ||
 	       mime_type_is_video (mime_type) ||
 	       mime_type_is_audio (mime_type);
 }
@@ -782,11 +782,37 @@ get_sample_name (const char *filename)
 }
 
 
+GHashTable *static_strings = NULL;
+
+
+static const char *
+get_static_string (const char *s)
+{
+	const char *result;
+
+	if (s == NULL)
+		return NULL;
+
+	if (static_strings == NULL)
+		static_strings = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+
+	if (! g_hash_table_lookup_extended (static_strings, s, (gpointer*) &result, NULL)) {
+		result = g_strdup (s);
+		g_hash_table_insert (static_strings,
+				     (gpointer) result,
+				     GINT_TO_POINTER (1));
+	}
+
+	return result;
+}
+
+
 const char*
 get_file_mime_type (const char *filename,
 		    gboolean    fast_file_type)
 {
 	const char *result = NULL;
+	const char *extension;
 
 	if (filename == NULL)
 		return NULL;
@@ -813,23 +839,28 @@ get_file_mime_type (const char *filename,
 
 	} else {
 		if (uri_scheme_is_file (filename))
-                        filename = get_file_path_from_uri (filename);
+			filename = get_file_path_from_uri (filename);
 		result = gnome_vfs_get_file_mime_type (filename, NULL, FALSE);
 	}
 
-	const char *extension = get_filename_extension (filename);
+	result = get_static_string (result);
 
 	/* Check files with special or problematic extensions */
+	extension = get_filename_extension (filename);
 	if (extension != NULL) {
 
 		/* Raw NEF files are sometimes mis-recognized as tiff files. Fix that. */
-		if (!strcmp (result,"image/tiff") && !strcasecmp (extension, "nef"))
+		if (!strcmp (result, "image/tiff") && !strcasecmp (extension, "nef"))
 			return "image/x-nikon-nef";
 
+		/* Raw CR2 files are sometimes mis-recognized as tiff files. Fix that. */
+                if (!strcmp (result, "image/tiff") && !strcasecmp (extension, "cr2"))
+                        return "image/x-canon-crw";
+
 		/* Check unrecognized binary types for special types that are not
 		   handled correctly in the normal mime databases. */
 
-		if ( (result==NULL) || !strcmp (result, "application/octet-stream")) {
+		if ((result == NULL) || (strcmp (result, "application/octet-stream") == 0)) {
 
 			/* If the file extension is not recognized, or the content is
 			   determined to be binary data (octet-stream), check for HDR file
@@ -844,7 +875,7 @@ get_file_mime_type (const char *filename,
 
 			/* Bug 329072: gnome-vfs doesn't recognize pcx files.
 			   This is the work-around until bug 329072 is fixed. */
-			if ( !strcasecmp (extension, "pcx") )
+			if (strcasecmp (extension, "pcx") == 0)
 				return "image/x-pcx";
 		}
 	}
@@ -873,7 +904,7 @@ image_is_type (const char *name,
 
 static gboolean
 image_is_type__gconf_file_type (const char *name,
-	                       const char *type)
+			       const char *type)
 {
 	return image_is_type (name, type, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE));
 }
@@ -908,7 +939,14 @@ mime_type_is_hdr (const char *mime_type)
 {
 	/* Note that some HDR file extensions have been hard-coded into
 	   the get_file_mime_type function above. */
-        return mime_type_is (mime_type, "image/x-hdr");
+	return mime_type_is (mime_type, "image/x-hdr");
+}
+
+
+gboolean
+mime_type_is_tiff (const char *mime_type)
+{
+	return mime_type_is (mime_type, "image/tiff");
 }
 
 
@@ -1179,6 +1217,36 @@ get_uri_scheme (const char *uri)
 }
 
 
+const char *
+remove_host_from_uri (const char *uri)
+{
+	const char *idx;
+
+	idx = strstr (uri, "://");
+	if (idx == NULL)
+		return uri;
+	idx = strstr (idx + 3, "/");
+	if (idx == NULL)
+		return NULL;
+	return idx + 1;
+}
+
+
+char *
+get_uri_host (const char *uri)
+{
+	const char *idx;
+
+	idx = strstr (uri, "://");
+	if (idx == NULL)
+		return NULL;
+	idx = strstr (idx + 3, "/");
+	if (idx == NULL)
+		return NULL;
+	return g_strndup (uri, (idx - uri));
+}
+
+
 gboolean
 uri_has_scheme (const char *uri)
 {
@@ -1290,7 +1358,7 @@ get_uri_display_name (const char *uri)
 			base_uri_len = strlen (remove_scheme_from_uri (base_uri));
 			g_free (base_uri);
 
-			name = g_strdup (tmp_path + 1 + base_uri_len);
+			name = gnome_vfs_unescape_string_for_display (tmp_path + 1 + base_uri_len);
 		} else {
 			const char *base_path;
 			int         base_path_len;
@@ -1324,24 +1392,24 @@ G_CONST_RETURN char *
 file_name_from_path (const char *file_name)
 {
 	register gssize base;
-        register gssize last_char;
+	register gssize last_char;
 
-        if (file_name == NULL)
-                return NULL;
+	if (file_name == NULL)
+		return NULL;
 
-        if (file_name[0] == '\0')
-                return "";
+	if (file_name[0] == '\0')
+		return "";
 
-        last_char = strlen (file_name) - 1;
+	last_char = strlen (file_name) - 1;
 
-        if (file_name [last_char] == G_DIR_SEPARATOR)
-                return "";
+	if (file_name [last_char] == G_DIR_SEPARATOR)
+		return "";
 
-        base = last_char;
-        while ((base >= 0) && (file_name [base] != G_DIR_SEPARATOR))
-                base--;
+	base = last_char;
+	while ((base >= 0) && (file_name [base] != G_DIR_SEPARATOR))
+		base--;
 
-        return file_name + base + 1;
+	return file_name + base + 1;
 }
 
 
@@ -1530,7 +1598,7 @@ remove_special_dirs_from_path (const char *uri)
 {
 	const char  *path;
 	char       **pathv;
-	GList       *list = NULL, *scan;
+	GList       *list = NULL;
 	int          i;
 	GString     *result_s;
 	char        *scheme;
@@ -1539,7 +1607,8 @@ remove_special_dirs_from_path (const char *uri)
 
 	scheme = get_uri_scheme (uri);
 
-	g_assert ((scheme != NULL) || g_path_is_absolute (uri));
+	if ((scheme == NULL) && ! g_path_is_absolute (uri))
+		return g_strdup (uri);
 
 	path = remove_scheme_from_uri (uri);
 
@@ -1550,10 +1619,9 @@ remove_special_dirs_from_path (const char *uri)
 
 	/* Trimmed uris might not start with a slash */
 	if (*path != '/')
-		start_at=0;
+		start_at = 0;
 	else
-		start_at=1;
-
+		start_at = 1;
 
 	/* Ignore first slash, if present. It will be re-added later. */
 	for (i = start_at; pathv[i] != NULL; i++) {
@@ -1576,7 +1644,7 @@ remove_special_dirs_from_path (const char *uri)
 	if (scheme != NULL) {
 		g_string_append (result_s, scheme);
 
-		if (start_at==0)
+		if (start_at == 0)
 			/* delete trailing slash, because an extra one is added below */
 			g_string_truncate (result_s, result_s->len - 1);
 
@@ -1586,6 +1654,8 @@ remove_special_dirs_from_path (const char *uri)
 	if (list == NULL)
 		g_string_append_c (result_s, '/');
 	else {
+		GList *scan;
+
 		list = g_list_reverse (list);
 		for (scan = list; scan; scan = scan->next) {
 			g_string_append_c (result_s, '/');
@@ -1628,92 +1698,177 @@ new_path_from_uri (GnomeVFSURI *uri)
 }
 
 
-GnomeVFSResult
-resolve_all_symlinks (const char  *text_uri,
-		      char       **resolved_text_uri)
+static char *
+build_uri (const char *s1,
+	   const char *s2)
 {
-	GnomeVFSResult    res = GNOME_VFS_OK;
-	char             *my_text_uri;
-	GnomeVFSFileInfo *info;
-	const char       *p;
-	int               n_followed_symlinks = 0;
-	gboolean          first_level = TRUE;
+	char *s = NULL;
+
+	if ((s1 == NULL) && (s2 == NULL))
+		return NULL;
+
+	if ((s1 == NULL) || (strcmp (s1, "") == 0))
+		return g_strdup (s2);
+	if ((s2 == NULL) || (strcmp (s2, "") == 0))
+		return g_strdup (s1);
+
+	if ((s1[strlen (s1) - 1] == GNOME_VFS_URI_PATH_CHR) || (s2[0] == GNOME_VFS_URI_PATH_CHR))
+		s = g_strconcat (s1, s2, NULL);
+	else
+		s = g_strconcat (s1, GNOME_VFS_URI_PATH_STR, s2, NULL);
+
+	return s;
+}
+
+
+GnomeVFSResult
+resolve_symlinks (const char  *text_uri,
+		  const char  *relative_link,
+		  char       **resolved_text_uri,
+		  int          n_followed_symlinks)
+{
+	GnomeVFSResult     result = GNOME_VFS_OK;
+	char              *resolved_uri;
+	char 		  *uri;
+	char              *tmp;
+	GnomeVFSFileInfo  *info;
+	const char        *path;
+	char             **names;
+	int                i;
 
 	*resolved_text_uri = NULL;
 
 	if (text_uri == NULL)
-		return res;
+		return GNOME_VFS_OK;
+	if (*text_uri == '\0')
+		return GNOME_VFS_ERROR_INVALID_URI;
 
-	my_text_uri = g_strdup (text_uri);
 	info = gnome_vfs_file_info_new ();
 
-	for (p = remove_scheme_from_uri(my_text_uri); (p != NULL) && (*p != 0); ) {
-		char           *new_text_uri;
-		GnomeVFSURI    *new_uri;
+	resolved_uri = get_uri_host (text_uri);
+	if (resolved_uri == NULL)
+		resolved_uri = g_strdup ("file://");
 
-		while (*p == GNOME_VFS_URI_PATH_CHR)
-			p++;
-		while (*p != 0 && *p != GNOME_VFS_URI_PATH_CHR)
-			p++;
+	tmp = build_uri (text_uri, relative_link);
+	uri = remove_special_dirs_from_path (tmp);
+	g_free (tmp);
 
-		new_text_uri = g_strndup (my_text_uri, p - my_text_uri);
-		new_uri = new_uri_from_path (new_text_uri);
-		g_free (new_text_uri);
+	/* split the uri and resolve one name at a time. */
 
-		gnome_vfs_file_info_clear (info);
-		res = gnome_vfs_get_file_info_uri (new_uri, info, GNOME_VFS_FILE_INFO_DEFAULT);
-
-		if (res != GNOME_VFS_OK) {
-			char *old_uri = my_text_uri;
-			my_text_uri = g_build_filename (old_uri, p, NULL);
-			g_free (old_uri);
-			p = NULL;
-
-		} else if (info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK &&
-			   info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME) {
-			GnomeVFSURI *resolved_uri;
-			char        *tmp_resolved_text_uri = NULL;
-			char        *symbolic_link = NULL;
-
-			n_followed_symlinks++;
-			if (n_followed_symlinks > MAX_SYMLINKS_FOLLOWED) {
-				res = GNOME_VFS_ERROR_TOO_MANY_LINKS;
-				gnome_vfs_uri_unref (new_uri);
-				goto out;
-			}
-
-			if (first_level && (info->symlink_name[0] != '/'))
-				symbolic_link = g_strconcat ("/", info->symlink_name, NULL);
-			else
-				symbolic_link = g_strdup (info->symlink_name);
-			resolved_uri = gnome_vfs_uri_resolve_relative (new_uri, symbolic_link);
-			g_free (symbolic_link);
-
-			tmp_resolved_text_uri = new_path_from_uri (resolved_uri);
-			gnome_vfs_uri_unref (resolved_uri);
-
-			if (*p != 0) {
-				char *old_uri = my_text_uri;
-				my_text_uri = g_build_filename (tmp_resolved_text_uri, p, NULL);
-				g_free (old_uri);
-				g_free (tmp_resolved_text_uri);
-			} else {
-				g_free (my_text_uri);
-				my_text_uri = tmp_resolved_text_uri;
-			}
-
-			p = my_text_uri;
-		}
-		first_level = FALSE;
-
-		gnome_vfs_uri_unref (new_uri);
+	path = remove_host_from_uri (uri);
+	if (path == NULL) {
+		*resolved_text_uri = resolved_uri;
+		return GNOME_VFS_OK;
 	}
 
-	res = GNOME_VFS_OK;
-	*resolved_text_uri = my_text_uri;
- out:
+	names = g_strsplit (path, GNOME_VFS_URI_PATH_STR, -1);
+	g_free (uri);
+
+	for (i = 0; (result == GNOME_VFS_OK) && (names[i] != NULL); i++) {
+		char  *try_uri;
+		char  *symlink;
+	    	char **symlink_names;
+	    	int    j;
+	    	char  *base_uri;
+
+		if (strcmp (names[i], "") == 0)
+			continue;
+
+		gnome_vfs_file_info_clear (info);
+
+		try_uri = g_strconcat (resolved_uri, GNOME_VFS_URI_PATH_STR, names[i], NULL);
+
+		result = gnome_vfs_get_file_info (try_uri, info, GNOME_VFS_FILE_INFO_DEFAULT);
+		if (result != GNOME_VFS_OK) {
+			g_free (try_uri);
+			break;
+		}
+
+		/* if names[i] isn't a symbolic link add it to the resolved uri and continue */
+
+		if (!((info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK) &&
+		      (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME))) {
+
+			g_free (resolved_uri);
+			resolved_uri = try_uri;
+
+			continue;
+		}
+
+		g_free (try_uri);
+
+		/* names[i] is a symbolic link */
+
+		n_followed_symlinks++;
+		if (n_followed_symlinks > MAX_SYMLINKS_FOLLOWED) {
+			result = GNOME_VFS_ERROR_TOO_MANY_LINKS;
+			break;
+		}
+
+		/* get the symlink escaping the value info->symlink_name */
+
+		symlink = g_strdup ("");
+		symlink_names = g_strsplit (info->symlink_name, GNOME_VFS_URI_PATH_STR, -1);
+		for (j = 0; symlink_names[j] != NULL; j++) {
+			char *symlink_name = symlink_names[j];
+	    		char *e_symlink_name;
+
+		    	if ((strcmp (symlink_name, "..") == 0) || (strcmp (symlink_name, ".") == 0))
+		    		e_symlink_name = g_strdup (symlink_name);
+		    	if (strcmp (symlink_name, "") == 0)
+		    		e_symlink_name = g_strdup (GNOME_VFS_URI_PATH_STR);
+		    	else
+		    		e_symlink_name = gnome_vfs_escape_string (symlink_name);
+
+		    	if (strcmp (symlink, "") == 0) {
+		    		g_free (symlink);
+		    		symlink = e_symlink_name;
+		    	}
+		    	else {
+		    		char *tmp;
+
+		   		tmp = build_uri (symlink, e_symlink_name);
+
+	    			g_free (symlink);
+	    			g_free (e_symlink_name);
+
+	    			symlink = tmp;
+	    		}
+	    	}
+	    	g_strfreev (symlink_names);
+
+		/* if the symlink is absolute reset the base uri, else use
+		 * the currently resolved uri as base. */
+
+	    	if (symlink[0] == GNOME_VFS_URI_PATH_CHR) {
+	    		g_free (resolved_uri);
+	    		base_uri = get_uri_scheme (text_uri);
+	    	} else
+	    		base_uri = resolved_uri;
+
+		/* resolve the new uri recursively */
+
+	    	result = resolve_symlinks (base_uri, symlink, &resolved_uri, n_followed_symlinks);
+
+	    	g_free (base_uri);
+		g_free (symlink);
+	}
+
+	g_strfreev (names);
 	gnome_vfs_file_info_unref (info);
-	return res;
+
+	if (result == GNOME_VFS_OK)
+		*resolved_text_uri = resolved_uri;
+
+	return result;
+}
+
+
+GnomeVFSResult
+resolve_all_symlinks (const char  *text_uri,
+		      char       **resolved_text_uri)
+{
+	return resolve_symlinks (text_uri, "", resolved_text_uri, 0);
 }
 
 
@@ -2264,29 +2419,29 @@ is_local_file (const char *filename)
 char *
 get_cache_full_path (const char *relative_path, const char *extension)
 {
-        char *path;
-        char *separator;
+	char *path;
+	char *separator;
 
-        /* Do not allow .. in the relative_path otherwise the user can go
-         * to any directory, while he shouldn't exit from RC_CATALOG_DIR. */
-        if ((relative_path != NULL) && (strstr (relative_path, "..") != NULL))
-                return NULL;
+	/* Do not allow .. in the relative_path otherwise the user can go
+	 * to any directory, while he shouldn't exit from RC_CATALOG_DIR. */
+	if ((relative_path != NULL) && (strstr (relative_path, "..") != NULL))
+		return NULL;
 
-        if (relative_path == NULL)
-                separator = NULL;
-        else
-                separator = (relative_path[0] == '/') ? "" : "/";
+	if (relative_path == NULL)
+		separator = NULL;
+	else
+		separator = (relative_path[0] == '/') ? "" : "/";
 
-        path = g_strconcat ("file://",
-                            g_get_home_dir (),
-                            "/",
-                            RC_REMOTE_CACHE_DIR,
-                            separator,
-                            relative_path,
+	path = g_strconcat ("file://",
+			    g_get_home_dir (),
+			    "/",
+			    RC_REMOTE_CACHE_DIR,
+			    separator,
+			    relative_path,
 			    extension,
-                            NULL);
+			    NULL);
 
-        return path;
+	return path;
 }
 
 
@@ -2301,7 +2456,7 @@ prune_cache (void)
 				g_get_home_dir (),
 				"/",
 				RC_REMOTE_CACHE_DIR,
-				" -mindepth 1 -type f -ctime +2 -print0 | xargs -0 rm -rf",
+				" -type f -ctime +2 | xargs rm -rf",
 				NULL );
 	system (command);
 	g_free (command);
@@ -2318,8 +2473,8 @@ obtain_local_file (const char *remote_filename)
 	/* If the file is local, simply return a copy of the filename, without
 	   any "file:///" prefix. */
 
-        if (is_local_file (remote_filename))
-        	return get_local_path_from_uri (remote_filename);
+	if (is_local_file (remote_filename))
+		return get_local_path_from_uri (remote_filename);
 
 	/* If the file is remote, copy it to a local cache. */
 
@@ -2342,11 +2497,11 @@ obtain_local_file (const char *remote_filename)
 		GnomeVFSResult  result;
 
 		result = gnome_vfs_xfer_uri (source_uri, target_uri,
-                	                     GNOME_VFS_XFER_DEFAULT | GNOME_VFS_XFER_FOLLOW_LINKS,
-               	        	             GNOME_VFS_XFER_ERROR_MODE_ABORT,
-                       	        	     GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-                               	     	     NULL,
-                                     	     NULL);
+					     GNOME_VFS_XFER_DEFAULT | GNOME_VFS_XFER_FOLLOW_LINKS,
+						    GNOME_VFS_XFER_ERROR_MODE_ABORT,
+						    GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+							 NULL,
+						  NULL);
 
 		gnome_vfs_uri_unref (source_uri);
 		gnome_vfs_uri_unref (target_uri);
@@ -2366,28 +2521,28 @@ obtain_local_file (const char *remote_filename)
 
 gboolean
 copy_cache_file_to_remote_uri (const char *local_filename,
-                               const char *dest_uri)
+			       const char *dest_uri)
 {
-        /* make a remote copy of a local cache file */
+	/* make a remote copy of a local cache file */
 
-        GnomeVFSURI    *source_uri;
-        GnomeVFSURI    *target_uri;
-        GnomeVFSResult  result;
+	GnomeVFSURI    *source_uri;
+	GnomeVFSURI    *target_uri;
+	GnomeVFSResult  result;
 
-        source_uri = gnome_vfs_uri_new (local_filename);
-        target_uri = gnome_vfs_uri_new (dest_uri);
+	source_uri = gnome_vfs_uri_new (local_filename);
+	target_uri = gnome_vfs_uri_new (dest_uri);
 
-        result = gnome_vfs_xfer_uri (source_uri, target_uri,
-                                     GNOME_VFS_XFER_DEFAULT | GNOME_VFS_XFER_FOLLOW_LINKS,
-                                     GNOME_VFS_XFER_ERROR_MODE_ABORT,
-                                     GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-                                     NULL,
-                                     NULL);
+	result = gnome_vfs_xfer_uri (source_uri, target_uri,
+				     GNOME_VFS_XFER_DEFAULT | GNOME_VFS_XFER_FOLLOW_LINKS,
+				     GNOME_VFS_XFER_ERROR_MODE_ABORT,
+				     GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+				     NULL,
+				     NULL);
 
-        gnome_vfs_uri_unref (target_uri);
-        gnome_vfs_uri_unref (source_uri);
+	gnome_vfs_uri_unref (target_uri);
+	gnome_vfs_uri_unref (source_uri);
 
-        return (result == GNOME_VFS_OK);
+	return (result == GNOME_VFS_OK);
 }
 
 
@@ -2407,23 +2562,25 @@ get_pixbuf_using_external_converter (const char *url,
 	char	   *cache_file_esc;
 	char	   *input_file_esc;
 	char	   *command;
-	GdkPixbuf  *pixbuf = NULL;
-	gboolean    is_raw;
-	gboolean    is_hdr;
+        GdkPixbuf  *pixbuf = NULL;
+        gboolean    is_raw;
+        gboolean    is_hdr;
+	gboolean    is_tiff;
 
-	path = gnome_vfs_unescape_string (url, NULL);
+        path = gnome_vfs_unescape_string (url, NULL);
 
-	is_raw = mime_type_is_raw (mime_type);
-	is_hdr = !is_raw;
+        is_raw = mime_type_is_raw (mime_type);
+	is_hdr = mime_type_is_hdr (mime_type);
+	is_tiff = mime_type_is_tiff (mime_type);
 
-	md5_file = gnome_thumbnail_md5 (path);
+        md5_file = gnome_thumbnail_md5 (path);
 
-	input_file_esc = shell_escape (path);
+        input_file_esc = shell_escape (path);
 
-	if (is_raw)
-		/* Same file used for RAW thumbnailing and full image loading */
-		cache_file_full = get_cache_full_path (md5_file, "conv.pnm");
-	else if (requested_width_if_used > 0)
+	if (is_raw || is_tiff)
+                /* Same file used for RAW thumbnailing and full image loading */
+                cache_file_full = get_cache_full_path (md5_file, "conv.pnm");
+	else if (is_hdr && requested_width_if_used > 0)
 		/* HDR: separate files for thumbnails, full images */
 		cache_file_full = get_cache_full_path (md5_file, "conv-thumb.tiff");
 	else
@@ -2443,19 +2600,21 @@ get_pixbuf_using_external_converter (const char *url,
 	g_assert (is_local_file (cache_file));
 
 	/* Do nothing if an up-to-date converted file is already in the cache */
-        if (!path_is_file (cache_file) ||
-            (get_file_mtime (path) > get_file_mtime (cache_file))) {
+	if (!path_is_file (cache_file) ||
+	    (get_file_mtime (path) > get_file_mtime (cache_file))) {
 
 		if (is_raw) {
 			/* RAW files - dcraw doesn't support thumbnailing very
 			   elegantly (even with the -e option), so we just convert
 			   the full file (which will speed up image loading). */
-		        command = g_strconcat ( "dcraw -c ",
-        	        	                input_file_esc,
-                	        	        " > ",
-                        	        	cache_file_esc,
-                                		NULL );
-		} else {
+			command = g_strconcat ( "dcraw -c ",
+						input_file_esc,
+						" > ",
+						cache_file_esc,
+						NULL );
+		}
+
+		if (is_hdr) {
 			/* HDR files. We can use the pfssize tool to speed up
 			   thumbnail generation considerably, so we treat
 			   thumbnailing as a special case. */
@@ -2463,38 +2622,51 @@ get_pixbuf_using_external_converter (const char *url,
 
 			if (requested_width_if_used > 0)
 				resize_command = g_strdup_printf (" | pfssize --maxx %d --maxy %d",
-						                  requested_width_if_used,
+								  requested_width_if_used,
 								  requested_height_if_used);
 			else
 				resize_command = g_strdup_printf (" ");
 
-        	        command = g_strconcat ( "pfsin ",
-                	                        input_file_esc,
+			command = g_strconcat ( "pfsin ",
+						input_file_esc,
 						resize_command,
-                        	                " |  pfsclamp  --rgb  | pfstmo_drago03 | pfsout ",
-                                	        cache_file_esc,
-                                        	NULL );
+						" |  pfsclamp  --rgb  | pfstmo_drago03 | pfsout ",
+						cache_file_esc,
+						NULL );
 			g_free (resize_command);
 		}
 
+		if (is_tiff) {
+			/* The standard gdk thumbnailer doesn't handle large-dimension tiff
+			   images elegantly, bugs 142428 and 160460. Memory blows up. We can
+			   do it more efficiently. */
+
+			command = g_strdup_printf ( "tifftopnm -byrow %s 2>/dev/null | pamscale -xyfit %d %d 2>/dev/null 1> %s",
+					 	    input_file_esc,
+						    requested_width_if_used,
+						    requested_height_if_used,
+						    cache_file_esc);
+		}
+
 		if (gnome_vfs_is_executable_command_string (command))
 		       	system (command);
 
-        	g_free (command);
+		g_free (command);
 	}
 
 	if (path_is_file (cache_file))
 		pixbuf = gdk_pixbuf_new_from_file (cache_file, NULL);
 
-	/* Thumbnail files are already cached, so delete the conversion cache 
-	   copies of HDR files. */
-	if (requested_width_if_used > 0 && is_hdr)
+	/* Thumbnail files are already cached, so delete the conversion cache copies,
+	   except for raw files (because the same cache file is used for raw
+ 	   thumbnails and raw full images). */
+	if (requested_width_if_used > 0 && !is_raw)
 		file_unlink (cache_file);
 
 	g_free (cache_file);
-        g_free (cache_file_esc);
-        g_free (input_file_esc);
-        g_free (path);
+	g_free (cache_file_esc);
+	g_free (input_file_esc);
+	g_free (path);
 
 	return pixbuf;
 }
@@ -2508,60 +2680,60 @@ gth_pixbuf_new_from_video (const char             *path,
       	GdkPixbuf *pixbuf = NULL;
 	time_t     mtime;
 	char      *real_path = NULL;
-        char      *existing_video_thumbnail;
+	char      *existing_video_thumbnail;
 
 	if (resolve_all_symlinks (path, &real_path) != GNOME_VFS_OK)
 		return NULL;
 
-        mtime = get_file_mtime (real_path);
-        existing_video_thumbnail = gnome_thumbnail_factory_lookup (factory,
-                                                                   real_path,
-                                                                   mtime);
+	mtime = get_file_mtime (real_path);
+	existing_video_thumbnail = gnome_thumbnail_factory_lookup (factory,
+								   real_path,
+								   mtime);
 
 	if (existing_video_thumbnail != NULL) {
 		char *thumbnail_path = get_local_path_from_uri (existing_video_thumbnail);
 
 		pixbuf = gdk_pixbuf_new_from_file (thumbnail_path, error);
 		g_free (thumbnail_path);
-                g_free (existing_video_thumbnail);
-        }
-        else if (gnome_thumbnail_factory_has_valid_failed_thumbnail (factory, real_path, mtime)) {
+		g_free (existing_video_thumbnail);
+	}
+	else if (gnome_thumbnail_factory_has_valid_failed_thumbnail (factory, real_path, mtime)) {
 		g_free (real_path);
-        	return NULL;
+		return NULL;
 	}
 	else {
 		pixbuf = gnome_thumbnail_factory_generate_thumbnail (factory,
-                                                                     real_path,
-                                                                     get_mime_type (real_path));
-                if (pixbuf != NULL)
+								     real_path,
+								     get_mime_type (real_path));
+		if (pixbuf != NULL)
 			gnome_thumbnail_factory_save_thumbnail (factory,
-                                                                pixbuf,
-                                                                real_path,
-                                                                mtime);
+								pixbuf,
+								real_path,
+								mtime);
 	}
 
 	g_free (real_path);
 
-        return pixbuf;
+	return pixbuf;
 }
 
 
 GdkPixbuf*
 gth_pixbuf_new_from_uri (const char  *uri,
 			 GError     **error,
-                         gint         requested_width_if_used,
-                         gint         requested_height_if_used,
-                         const char  *mime_type)
+			 gint         requested_width_if_used,
+			 gint         requested_height_if_used,
+			 const char  *mime_type)
 {
 	GdkPixbuf *pixbuf = NULL;
 	char      *local_file = NULL;
 
-        if (uri == NULL)
-                return NULL;
+	if (uri == NULL)
+		return NULL;
 
-        /* gdk_pixbuf does not support VFS URIs directly, so
+	/* gdk_pixbuf does not support VFS URIs directly, so
 	   make a local cache copy of remote files. */
-        local_file = obtain_local_file (uri);
+	local_file = obtain_local_file (uri);
 	if (local_file == NULL)
 		return NULL;
 
@@ -2576,16 +2748,18 @@ gth_pixbuf_new_from_uri (const char  *uri,
 		pixbuf = or_gdkpixbuf_extract_thumbnail (local_file, requested_width_if_used);
 #endif
 
-	/* Use dcraw for raw images and pfstools for HDR images. */
+	/* Use dcraw for raw images, pfstools for HDR images, and tifftopnm for tiff thumbnails */
 	if ((pixbuf == NULL) &&
-	    (mime_type_is_raw (mime_type) || mime_type_is_hdr (mime_type)))
-		pixbuf = get_pixbuf_using_external_converter (local_file, 
+	     (mime_type_is_raw (mime_type) ||
+	      mime_type_is_hdr (mime_type) ||
+	      (mime_type_is_tiff (mime_type) && (requested_width_if_used > 0))))
+		pixbuf = get_pixbuf_using_external_converter (local_file,
 							      mime_type,
 							      requested_width_if_used,
 							      requested_height_if_used);
 
 	/* Otherwise, use standard gdk_pixbuf loaders */
-        if (pixbuf == NULL)
+	if (pixbuf == NULL)
 		pixbuf = gdk_pixbuf_new_from_file (local_file, error);
 
 	g_free (local_file);
@@ -2603,46 +2777,46 @@ gth_pixbuf_animation_new_from_uri (const char 	          *filename,
 {
 	GdkPixbufAnimation *animation = NULL;
 	GdkPixbuf          *pixbuf = NULL;
-        char               *local_file = NULL;
+	char               *local_file = NULL;
 
 	if (mime_type == NULL)
 		return NULL;
 
-        /* The video thumbnailer can handle VFS URIs directly */
+	/* The video thumbnailer can handle VFS URIs directly */
 
-        if (mime_type_is_video (mime_type) && (factory != NULL)) {
+	if (mime_type_is_video (mime_type) && (factory != NULL)) {
 		pixbuf = gth_pixbuf_new_from_video (filename, factory, error);
 		if (pixbuf == NULL)
 			return NULL;
 		animation = gdk_pixbuf_non_anim_new (pixbuf);
-                g_object_unref (pixbuf);
+		g_object_unref (pixbuf);
 		return animation;
 	}
 
-        /* gdk_pixbuf and libopenraw do not support VFS URIs directly,
+	/* gdk_pixbuf and libopenraw do not support VFS URIs directly,
 	   so make a local cache copy of remote files. */
-        local_file = obtain_local_file (filename);
+	local_file = obtain_local_file (filename);
 
-        if (local_file == NULL)
-                return NULL;
+	if (local_file == NULL)
+		return NULL;
 
 	/* The jpeg thumbnailer can handle VFS URIs directly, but it is
 	   actually 3 times slower than copying it to a local cache.
 	   (Tested with ~ 3.7 MB jpeg files over ssh:// on DSL lines). */
 
 	/* Thumbnailing mode is signaled by requested_width_if_used > 0. */
-        if (mime_type_is (mime_type, "image/jpeg") && (requested_width_if_used > 0)) {
-                pixbuf = f_load_scaled_jpeg (local_file,
-                                             requested_width_if_used,
-                                             requested_height_if_used,
-                                             NULL, NULL);
+	if (mime_type_is (mime_type, "image/jpeg") && (requested_width_if_used > 0)) {
+		pixbuf = f_load_scaled_jpeg (local_file,
+					     requested_width_if_used,
+					     requested_height_if_used,
+					     NULL, NULL);
 		if (pixbuf == NULL)
 			return NULL;
-                animation = gdk_pixbuf_non_anim_new (pixbuf);
-                g_object_unref (pixbuf);
+		animation = gdk_pixbuf_non_anim_new (pixbuf);
+		g_object_unref (pixbuf);
 		g_free (local_file);
-                return animation;
-        }
+		return animation;
+	}
 
 	/* gifs: use gdk_pixbuf_animation_new_from_file */
 	if (mime_type_is (mime_type, "image/gif")) {
@@ -2655,17 +2829,17 @@ gth_pixbuf_animation_new_from_uri (const char 	          *filename,
 	   non-animated pixbuf, and convert to a single-frame animation. */
 	if (pixbuf == NULL) {
 		char *local_uri = escape_uri(local_file);
-	        pixbuf = gth_pixbuf_new_from_uri (local_uri,
-				                  error,
+		pixbuf = gth_pixbuf_new_from_uri (local_uri,
+						  error,
 						  requested_width_if_used,
 						  requested_height_if_used,
 						  mime_type);
-	        g_free (local_uri);
+		g_free (local_uri);
 	}
 
-        if (pixbuf != NULL) {
-              	animation = gdk_pixbuf_non_anim_new (pixbuf);
-                g_object_unref (pixbuf);
+	if (pixbuf != NULL) {
+		      animation = gdk_pixbuf_non_anim_new (pixbuf);
+		g_object_unref (pixbuf);
 	}
 
 	g_free (local_file);
@@ -2720,3 +2894,4 @@ read_dot_hidden_file (const char *uri)
 
 	return hidden_files;
 }
+
