@@ -25,10 +25,12 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <libgnome/libgnome.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <glade/glade.h>
 #include "gtk-utils.h"
 #include "gconf-utils.h"
 #include "file-utils.h"
-
+#include "glib-utils.h"
 
 #define REQUEST_ENTRY_WIDTH 220
 
@@ -62,7 +64,7 @@ _gtk_image_new_from_inline (const guint8 *data)
 
 
 static GtkWidget *
-create_button (const char *stock_id, 
+create_button (const char *stock_id,
 	       const char *text)
 {
 	GtkWidget    *button;
@@ -147,11 +149,11 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	escaped_message = g_markup_escape_text (message, -1);
 	if (secondary_message != NULL) {
 		char *escaped_secondary_message = g_markup_escape_text (secondary_message, -1);
-		markup_text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s", 
+		markup_text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
 					       escaped_message,
 					       escaped_secondary_message);
 		g_free (escaped_secondary_message);
-	} else 
+	} else
 		markup_text = g_strdup (escaped_message);
 	gtk_label_set_markup (GTK_LABEL (label), markup_text);
 	g_free (markup_text);
@@ -159,22 +161,22 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	
+
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-	
+
 	gtk_box_pack_start (GTK_BOX (hbox), image,
 			    FALSE, FALSE, 0);
-	
+
 	gtk_box_pack_start (GTK_BOX (hbox), label,
 			    TRUE, TRUE, 0);
-	
+
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
 			    hbox,
 			    FALSE, FALSE, 0);
-	
+
 	gtk_widget_show_all (hbox);
-	
+
 	/* Add buttons */
 
 	if (first_button_text == NULL)
@@ -234,7 +236,7 @@ _gtk_request_dialog_run (GtkWindow        *parent,
 	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
 	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 
-	label = gtk_label_new (message);	
+	label = gtk_label_new (message);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -263,37 +265,40 @@ _gtk_request_dialog_run (GtkWindow        *parent,
 
 	gtk_box_pack_start (GTK_BOX (hbox), vbox,
 			    TRUE, TRUE, 0);
-	
+
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
 			    hbox,
 			    FALSE, FALSE, 0);
-	
+
 	gtk_widget_show_all (hbox);
-	
+
 	/* Add buttons */
 
 	button = create_button (GTK_STOCK_CANCEL, no_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d), 
-				      button, 
+	gtk_dialog_add_action_widget (GTK_DIALOG (d),
+				      button,
 				      GTK_RESPONSE_CANCEL);
 
 	/**/
 
 	button = create_button (GTK_STOCK_OK, yes_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d), 
+	gtk_dialog_add_action_widget (GTK_DIALOG (d),
 				      button,
 				      GTK_RESPONSE_YES);
 
 	/**/
 
-	gtk_dialog_set_default_response (GTK_DIALOG (d), 
+	gtk_dialog_set_default_response (GTK_DIALOG (d),
 					 GTK_RESPONSE_YES);
 	gtk_widget_grab_focus (entry);
 
 	/* Run dialog */
 
-	if (gtk_dialog_run (GTK_DIALOG (d)) == GTK_RESPONSE_YES) 
-		result = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
+	if (gtk_dialog_run (GTK_DIALOG (d)) == GTK_RESPONSE_YES)
+		/* Normalize unicode text to "NFC" form for consistency. */
+		result = g_utf8_normalize (gtk_entry_get_text (GTK_ENTRY (entry)),
+					   -1,
+					   G_NORMALIZE_NFC);
 	else
 		result = NULL;
 
@@ -330,43 +335,43 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
 	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 
-	label = gtk_label_new (message);	
+	label = gtk_label_new (message);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	
+
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-	
+
 	gtk_box_pack_start (GTK_BOX (hbox), image,
 			    FALSE, FALSE, 0);
-	
+
 	gtk_box_pack_start (GTK_BOX (hbox), label,
 			    TRUE, TRUE, 0);
-	
+
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
 			    hbox,
 			    FALSE, FALSE, 0);
-	
+
 	gtk_widget_show_all (hbox);
 
 	/* Add buttons */
 
 	button = create_button (GTK_STOCK_CANCEL, no_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d), 
-				      button, 
+	gtk_dialog_add_action_widget (GTK_DIALOG (d),
+				      button,
 				      GTK_RESPONSE_CANCEL);
 
 	/**/
 
 	button = create_button (GTK_STOCK_OK, yes_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d), 
-				      button, 
+	gtk_dialog_add_action_widget (GTK_DIALOG (d),
+				      button,
 				      GTK_RESPONSE_YES);
 
 	/**/
 
 	gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-	
+
 	return d;
 }
 
@@ -375,7 +380,7 @@ static void
 yesno__check_button_toggled_cb (GtkToggleButton *button,
 				const char      *gconf_key)
 {
-	eel_gconf_set_boolean (gconf_key, 
+	eel_gconf_set_boolean (gconf_key,
 			       ! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)));
 }
 
@@ -410,19 +415,19 @@ _gtk_yesno_dialog_with_checkbutton_new (GtkWindow        *parent,
 	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
 	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 
-	label = gtk_label_new (message);	
+	label = gtk_label_new (message);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	
+
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-	
+
 	gtk_box_pack_start (GTK_BOX (hbox), image,
 			    FALSE, FALSE, 0);
-	
+
 	gtk_box_pack_start (GTK_BOX (hbox), label,
 			    TRUE, TRUE, 0);
-	
+
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
 			    hbox,
 			    FALSE, FALSE, 0);
@@ -434,21 +439,21 @@ _gtk_yesno_dialog_with_checkbutton_new (GtkWindow        *parent,
 			    check_button,
 			    FALSE, FALSE, 0);
 	gtk_widget_show (check_button);
-	
+
 	gtk_widget_show_all (hbox);
 
 	/* Add buttons */
 
 	button = create_button (GTK_STOCK_CANCEL, no_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d), 
-				      button, 
+	gtk_dialog_add_action_widget (GTK_DIALOG (d),
+				      button,
 				      GTK_RESPONSE_CANCEL);
 
 	/**/
 
 	button = create_button (GTK_STOCK_OK, yes_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d), 
-				      button, 
+	gtk_dialog_add_action_widget (GTK_DIALOG (d),
+				      button,
 				      GTK_RESPONSE_YES);
 
 	/**/
@@ -456,10 +461,122 @@ _gtk_yesno_dialog_with_checkbutton_new (GtkWindow        *parent,
 	gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
 
 	g_signal_connect (G_OBJECT (check_button),
-			  "toggled", 
-			  G_CALLBACK (yesno__check_button_toggled_cb), 
+			  "toggled",
+			  G_CALLBACK (yesno__check_button_toggled_cb),
 			  (gpointer) gconf_key);
-	
+
+	return d;
+}
+
+
+GtkWidget*
+_gtk_message_dialog_with_checkbutton_new (GtkWindow        *parent,
+			 		  GtkDialogFlags    flags,
+			 		  const char       *stock_id,
+			 		  const char       *message,
+			 		  const char       *secondary_message,
+			 		  const char       *gconf_key,
+			 		  const char       *check_button_label,
+			 		  const char       *first_button_text,
+			 		  ...)
+{
+	GtkWidget  *d;
+	GtkWidget  *label;
+	GtkWidget  *image;
+	GtkWidget  *hbox;
+	GtkWidget  *check_button;
+	va_list     args;
+	const char *text;
+	int         response_id;
+	char       *escaped_message, *markup_text;
+
+	g_return_val_if_fail (message != NULL, NULL);
+
+	if (stock_id == NULL)
+		stock_id = GTK_STOCK_DIALOG_INFO;
+
+	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL);
+	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
+
+	gtk_dialog_set_has_separator (GTK_DIALOG (d), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (d), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (d)->vbox), 6);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (d)->vbox), 8);
+
+	/* Add label and image */
+
+	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
+	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+
+	label = gtk_label_new ("");
+
+	escaped_message = g_markup_escape_text (message, -1);
+	if (secondary_message != NULL) {
+		char *escaped_secondary_message = g_markup_escape_text (secondary_message, -1);
+		markup_text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
+					       escaped_message,
+					       escaped_secondary_message);
+		g_free (escaped_secondary_message);
+	} else
+		markup_text = g_strdup (escaped_message);
+	gtk_label_set_markup (GTK_LABEL (label), markup_text);
+	g_free (markup_text);
+	g_free (escaped_message);
+
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
+
+	hbox = gtk_hbox_new (FALSE, 6);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
+
+	gtk_box_pack_start (GTK_BOX (hbox), image,
+			    FALSE, FALSE, 0);
+
+	gtk_box_pack_start (GTK_BOX (hbox), label,
+			    TRUE, TRUE, 0);
+
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
+			    hbox,
+			    FALSE, FALSE, 0);
+
+	gtk_widget_show_all (hbox);
+
+	/* Add checkbutton */
+
+	check_button = gtk_check_button_new_with_mnemonic (check_button_label);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
+			    check_button,
+			    FALSE, FALSE, 0);
+	gtk_widget_show (check_button);
+
+	/* Add buttons */
+
+	if (first_button_text == NULL)
+		return d;
+
+	va_start (args, first_button_text);
+
+	text = first_button_text;
+	response_id = va_arg (args, gint);
+
+	while (text != NULL) {
+		gtk_dialog_add_button (GTK_DIALOG (d), text, response_id);
+
+		text = va_arg (args, gchar*);
+		if (text == NULL)
+			break;
+		response_id = va_arg (args, int);
+	}
+
+	va_end (args);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
+
+	g_signal_connect (G_OBJECT (check_button),
+			  "toggled",
+			  G_CALLBACK (yesno__check_button_toggled_cb),
+			  (gpointer) gconf_key);
+
 	return d;
 }
 
@@ -621,7 +738,7 @@ _gtk_entry_set_filename_text (GtkEntry   *entry,
 
 	if (text == NULL)
 		text = "";
-	utf8_text = g_filename_display_name (text);
+	utf8_text = gnome_vfs_unescape_string_for_display (text);
 	gtk_entry_set_text (entry, utf8_text);
 	g_free (utf8_text);
 }
@@ -637,7 +754,7 @@ _gtk_entry_get_filename_text (GtkEntry   *entry)
 	if (utf8_text == NULL)
 		return NULL;
 
-	text = g_filename_from_utf8 (utf8_text, -1, NULL, NULL, NULL);
+	text = escape_uri (utf8_text);
 
 	return text;
 }
@@ -651,7 +768,7 @@ _gtk_label_set_filename_text (GtkLabel   *label,
 
 	if (text == NULL)
 		text = "";
-	utf8_text = g_filename_display_name (text);
+	utf8_text = gnome_vfs_unescape_string_for_display (text);
 	gtk_label_set_text (label, utf8_text);
 	g_free (utf8_text);
 }
@@ -667,14 +784,14 @@ _gtk_label_get_filename_text (GtkLabel   *label)
 	if (utf8_text == NULL)
 		return NULL;
 
-	text = g_filename_from_utf8 (utf8_text, -1, NULL, NULL, NULL);
+	text = gnome_vfs_escape_string (utf8_text);
 
 	return text;
 }
 
 
 gboolean
-exec_command (const char *application, 
+exec_command (const char *application,
 	      GList      *file_list)
 {
         GString *command;
@@ -704,6 +821,144 @@ exec_command (const char *application,
 }
 
 
+void
+exec_shell_script (GtkWindow  *window,
+		   const char *script,
+		   GList      *file_list)
+{
+        GladeXML  *gui;
+        GtkWidget *dialog;
+        GtkWidget *label;
+        GtkWidget *bar;
+        GList     *scan;
+        int        i, n;
+
+	if ((script == NULL) || (file_list == NULL)) 
+		return;
+
+	/* Add a progress indicator */
+        gui = glade_xml_new (GTHUMB_GLADEDIR "/gthumb_tools.glade",
+                             NULL,
+                             NULL);
+
+        dialog = glade_xml_get_widget (gui, "hotkey_progress");
+        label = glade_xml_get_widget (gui, "progress_info");
+        bar = glade_xml_get_widget (gui, "progress_progressbar");
+
+        n = g_list_length (file_list);
+
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
+        gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+
+        gtk_widget_show (dialog);
+
+        while (gtk_events_pending())
+                gtk_main_iteration();
+
+	/* If the %F code is present, all selected files are processed by
+	   one script instance. Otherwise, each file is handled sequentially. */
+
+	if (strstr (script, "%F")) {
+		char *command = NULL;
+		char *file_list_string;
+
+		file_list_string = g_strdup (" ");
+
+	        for (scan = file_list; scan; scan = scan->next) {
+			char *filename;
+			char *e_filename;
+			char *new_file_list;
+		
+			if (is_local_file (scan->data))
+                                filename = gnome_vfs_unescape_string_for_display (remove_scheme_from_uri (scan->data));
+                        else
+	                        filename = gnome_vfs_unescape_string_for_display (scan->data);
+
+			e_filename = shell_escape (filename);
+
+			new_file_list = g_strconcat (file_list_string, e_filename, " ", NULL);
+
+			g_free (e_filename);
+			g_free (file_list_string);
+			file_list_string = g_strdup (new_file_list);
+
+			g_free (new_file_list);
+        	}
+		command = _g_substitute_pattern (script, 'F', file_list_string);
+		g_free (file_list_string);
+
+		system (command);
+		g_free (command);
+
+		_gtk_label_set_filename_text (GTK_LABEL (label), script);
+                gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (bar),
+                                               (gdouble) 1.0);
+                while (gtk_events_pending())
+                	gtk_main_iteration();
+	} else {
+	        i = 0;
+        	for (scan = file_list; scan; scan = scan->next) {
+                	char *filename;
+	                char *e_filename;
+			char *name_wo_ext = NULL;
+			char *extension = NULL;
+			char *parent = NULL;
+			char *command0 = NULL;
+			char *command1 = NULL;
+			char *command2 = NULL;
+			char *command3 = NULL;
+
+			if (is_local_file (scan->data))
+		                filename = gnome_vfs_unescape_string_for_display (remove_scheme_from_uri (scan->data));
+		        else
+		                filename = gnome_vfs_unescape_string_for_display (scan->data);
+
+			name_wo_ext = remove_extension_from_path (filename);
+			extension = g_filename_to_utf8 (strrchr (filename, '.'), -1, 0, 0, 0);
+			parent = remove_level_from_path (filename);
+	
+        	        e_filename = shell_escape (filename);
+			command3 = _g_substitute_pattern (script, 'f', e_filename);
+	                g_free (e_filename);
+
+			e_filename = shell_escape (name_wo_ext);
+			command2 = _g_substitute_pattern (command3, 'n', e_filename);
+			g_free (e_filename);
+			g_free (command3);
+			e_filename = shell_escape (extension);
+			command1 = _g_substitute_pattern (command2, 'e', e_filename);
+			g_free (e_filename);
+			g_free (command2);
+
+	                e_filename = shell_escape (parent);
+        	        command0 = _g_substitute_pattern (command1, 'p', e_filename);
+                	g_free (e_filename);		
+			g_free (command1);
+
+			g_free (filename);
+			g_free (name_wo_ext);
+			g_free (extension);
+			g_free (parent);
+
+			_gtk_label_set_filename_text (GTK_LABEL (label), command0);
+        	        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (bar),
+                	                               (gdouble) (i + 0.5) / n);
+
+			system (command0);
+			g_free (command0);
+
+	                while (gtk_events_pending())
+        	                gtk_main_iteration();
+
+			i++;
+	        }
+	}
+
+        gtk_widget_destroy (dialog);
+        g_object_unref (gui);	
+}
+
+
 /* This function from gnome-panel/panel-util.c
  * (C) 1997, 1998, 1999, 2000 The Free Software Foundation
  * Copyright 2000 Helix Code, Inc.
@@ -736,9 +991,9 @@ panel_find_icon (GtkIconTheme  *icon_theme,
                         return g_strdup (icon_name);
                 } else {
                         char *basename;
-			
+
 			basename = g_path_get_basename (icon_name);
-                        retval = panel_find_icon (icon_theme, 
+                        retval = panel_find_icon (icon_theme,
 						  basename,
                                                   size);
                         g_free (basename);
@@ -758,9 +1013,9 @@ panel_find_icon (GtkIconTheme  *icon_theme,
             *p = 0;
         }
 
-        icon_info = gtk_icon_theme_lookup_icon (icon_theme, 
+        icon_info = gtk_icon_theme_lookup_icon (icon_theme,
 						icon_no_extension,
-						size, 
+						size,
 						0);
 	retval = g_strdup (gtk_icon_info_get_filename (icon_info));
 
@@ -787,9 +1042,9 @@ create_pixbuf (GtkIconTheme  *icon_theme,
 	if (icon_path == NULL)
 		return NULL;
 
-	pixbuf = gdk_pixbuf_new_from_file (icon_path, NULL);
+	pixbuf = gth_pixbuf_new_from_uri (icon_path, NULL, 0, 0, NULL);
         g_free (icon_path);
-	
+
         if (pixbuf == NULL)
                 return NULL;
 
@@ -827,14 +1082,14 @@ create_image (GtkIconTheme  *icon_theme,
 	GdkPixbuf *pixbuf;
 
 	pixbuf = create_pixbuf (icon_theme, icon_path, icon_size);
-	
+
 	if (pixbuf == NULL)
 		return NULL;
 
 	icon = gtk_image_new ();
 	gtk_image_set_from_pixbuf (GTK_IMAGE (icon), pixbuf);
 	g_object_unref (pixbuf);
-	
+
 	gtk_widget_show (icon);
 
 	return icon;
