@@ -69,13 +69,17 @@
 #define REFRESH_RATE 10
 
 
+typedef struct _DialogData DialogData;
+typedef struct _AsyncOperationData AsyncOperationData;
+
+
 typedef enum {
 	GTH_IMPORTER_OP_LIST_ABILITIES,
 	GTH_IMPORTER_OP_AUTO_DETECT
 } GthImporterOp;
 
 
-typedef struct {
+struct _DialogData {
 	GthBrowser     *browser;
 	GladeXML       *gui;
 
@@ -111,7 +115,7 @@ typedef struct {
 
 	Camera              *camera;
 	gboolean             camera_setted, view_folder;
-        GPContext           *context;
+	GPContext           *context;
 	CameraAbilitiesList *abilities_list;
 	GPPortInfoList      *port_list;
 
@@ -147,7 +151,150 @@ typedef struct {
 
 	guint                idle_id;
 
-} DialogData;
+	AsyncOperationData  *aodata;
+};
+
+
+/* Pseudo-Async Operation */
+
+
+#define ASYNC_STEP_TIMEOUT 60
+
+typedef void (*AsyncOpFunc) (AsyncOperationData *aodata,
+			     DialogData         *data);
+
+struct _AsyncOperationData {
+	DialogData  *data;
+	char        *operation_info;
+	GList       *list, *scan;
+	int          total, current;
+	AsyncOpFunc  init_func, step_func, done_func;
+	guint        timer_id;
+};
+
+
+static AsyncOperationData *
+async_operation_new (const char  *operation_info,
+		     GList       *list,
+		     AsyncOpFunc  init_func,
+		     AsyncOpFunc  step_func,
+		     AsyncOpFunc  done_func,
+		     DialogData  *data)
+{
+	AsyncOperationData *aodata;
+
+	aodata = g_new0 (AsyncOperationData, 1);
+
+	if (operation_info != NULL)
+		aodata->operation_info = g_strdup (operation_info);
+	else
+		aodata->operation_info = NULL;
+	aodata->list = list;
+	aodata->init_func = init_func;
+	aodata->step_func = step_func;
+	aodata->done_func = done_func;
+	aodata->data = data;
+	aodata->total = g_list_length (aodata->list);
+	aodata->current = 1;
+
+	return aodata;
+}
+
+
+static void
+async_operation_free (AsyncOperationData *aodata)
+{
+	g_free (aodata->operation_info);
+	g_free (aodata);
+}
+
+
+static void main_dialog_set_sensitive (DialogData *data, gboolean value);
+static void update_info (DialogData *data);
+
+
+static gboolean
+async_operation_step (gpointer callback_data)
+{
+	AsyncOperationData *aodata = callback_data;
+	gboolean            interrupted;
+
+	if (aodata->timer_id != 0) {
+		g_source_remove (aodata->timer_id);
+		aodata->timer_id = 0;
+	}
+
+	g_mutex_lock (aodata->data->yes_or_no);
+	interrupted = aodata->data->interrupted;
+	aodata->data->update_ui = TRUE;
+	aodata->data->fraction = (float) aodata->current / aodata->total;
+	g_mutex_unlock (aodata->data->yes_or_no);
+
+	if ((aodata->scan == NULL) || interrupted) {
+		g_mutex_lock (aodata->data->yes_or_no);
+		aodata->data->async_operation = FALSE;
+		g_mutex_unlock (aodata->data->yes_or_no);
+
+		main_dialog_set_sensitive (aodata->data, TRUE);
+
+		if (aodata->done_func != NULL)
+			(*aodata->done_func) (aodata, aodata->data);
+		async_operation_free (aodata);
+
+		return FALSE;
+	}
+
+	if (aodata->step_func) {
+		(*aodata->step_func) (aodata, aodata->data);
+		update_info (aodata->data);
+	}
+
+	aodata->current++;
+	aodata->scan = aodata->scan->next;
+
+	aodata->timer_id = g_timeout_add (ASYNC_STEP_TIMEOUT,
+					  async_operation_step,
+					  aodata);
+
+	return FALSE;
+}
+
+
+static void
+async_operation_start (AsyncOperationData *aodata)
+{
+	aodata->timer_id = 0;
+	aodata->scan = aodata->list;
+	aodata->current = 1;
+	if (aodata->init_func)
+		(*aodata->init_func) (aodata, aodata->data);
+
+	main_dialog_set_sensitive (aodata->data, FALSE);
+
+	g_mutex_lock (aodata->data->yes_or_no);
+	aodata->data->async_operation = TRUE;
+	aodata->data->interrupted = FALSE;
+	if (aodata->data->progress_info != NULL)
+		g_free (aodata->data->progress_info);
+	aodata->data->progress_info = g_strdup (aodata->operation_info);
+	g_mutex_unlock (aodata->data->yes_or_no);
+
+	async_operation_step (aodata);
+}
+
+
+static void
+async_operation_cancel (AsyncOperationData *aodata)
+{
+	if (aodata->timer_id == 0)
+		return;
+	g_source_remove (aodata->timer_id);
+	aodata->timer_id = 0;
+	async_operation_free (aodata);
+}
+
+
+/**/
 
 
 /* called when the main dialog is closed. */
@@ -170,6 +317,11 @@ destroy_cb (GtkWidget  *widget,
 		data->idle_id = 0;
 	}
 
+	if (data->aodata != NULL) {
+		async_operation_cancel (data->aodata);
+		data->aodata = NULL;
+	}
+
 	/**/
 
 	g_mutex_lock (data->yes_or_no);
@@ -245,7 +397,7 @@ task_terminated (DialogData *data)
 static unsigned int
 ctx_progress_start_func (GPContext  *context,
 			 float       target,
-                         const char *format,
+			 const char *format,
 			 va_list     args,
 			 gpointer    callback_data)
 {
@@ -256,7 +408,7 @@ ctx_progress_start_func (GPContext  *context,
 	data->update_ui = TRUE;
 	data->interrupted = FALSE;
 	data->target = target;
-	data->fraction = 0.0;
+	/*data->fraction = 0.0;*/
 	if (data->progress_info != NULL)
 		g_free (data->progress_info);
 	locale_string = g_strdup_vprintf (format, args);
@@ -271,14 +423,14 @@ ctx_progress_start_func (GPContext  *context,
 static void
 ctx_progress_update_func (GPContext    *context,
 			  unsigned int  id,
-                          float         current,
+			  float         current,
 			  gpointer      callback_data)
 {
 	DialogData *data = callback_data;
 
 	g_mutex_lock (data->yes_or_no);
 	data->update_ui = TRUE;
-	data->fraction = current / data->target;
+	/*data->fraction = current / data->target;*/
 	g_mutex_unlock (data->yes_or_no);
 }
 
@@ -511,117 +663,7 @@ main_dialog_set_sensitive (DialogData *data,
 }
 
 
- /**/
-
-
-#define ASYNC_STEP_TIMEOUT 60
-
-typedef struct _AsyncOperationData AsyncOperationData;
-
-typedef void (*AsyncOpFunc) (AsyncOperationData *aodata,
-			     DialogData         *data);
-
-
-struct _AsyncOperationData {
-	DialogData  *data;
-	GList       *list, *scan;
-	int          total, current;
-	AsyncOpFunc  init_func, step_func, done_func;
-	guint        timer_id;
-};
-
-
-static AsyncOperationData *
-async_operation_new (GList       *list,
-		     AsyncOpFunc  init_func,
-		     AsyncOpFunc  step_func,
-		     AsyncOpFunc  done_func,
-		     DialogData  *data)
-{
-	AsyncOperationData *aodata;
-
-	aodata = g_new0 (AsyncOperationData, 1);
-
-	aodata->list = list;
-	aodata->init_func = init_func;
-	aodata->step_func = step_func;
-	aodata->done_func = done_func;
-	aodata->data = data;
-	aodata->total = g_list_length (aodata->list);
-	aodata->current = 1;
-
-	return aodata;
-}
-
-
-static gboolean
-async_operation_step (gpointer callback_data)
-{
-	AsyncOperationData *aodata = callback_data;
-	gboolean            interrupted;
-
-	if (aodata->timer_id != 0) {
-		g_source_remove (aodata->timer_id);
-		aodata->timer_id = 0;
-	}
-
-	g_mutex_lock (aodata->data->yes_or_no);
-	interrupted = aodata->data->interrupted;
-	aodata->data->update_ui = TRUE;
-	aodata->data->fraction = (float) aodata->current / aodata->total;
-	g_mutex_unlock (aodata->data->yes_or_no);
-
-	if ((aodata->scan == NULL) || interrupted) {
-		g_mutex_lock (aodata->data->yes_or_no);
-		aodata->data->async_operation = FALSE;
-		g_mutex_unlock (aodata->data->yes_or_no);
-
-		main_dialog_set_sensitive (aodata->data, TRUE);
-
-		if (aodata->done_func != NULL)
-			(*aodata->done_func) (aodata, aodata->data);
-		g_free (aodata);
-
-		return FALSE;
-	}
-
-	if (aodata->step_func) {
-		(*aodata->step_func) (aodata, aodata->data);
-		update_info (aodata->data);
-	}
-
-	aodata->current++;
-	aodata->scan = aodata->scan->next;
-
-	aodata->timer_id = g_timeout_add (ASYNC_STEP_TIMEOUT,
-					  async_operation_step,
-					  aodata);
-
-	return FALSE;
-}
-
-
-static void
-async_operation_start (AsyncOperationData *aodata)
-{
-	aodata->timer_id = 0;
-	aodata->scan = aodata->list;
-	aodata->current = 1;
-	if (aodata->init_func)
-		(*aodata->init_func) (aodata, aodata->data);
-
-	main_dialog_set_sensitive (aodata->data, FALSE);
-
-	g_mutex_lock (aodata->data->yes_or_no);
-	aodata->data->async_operation = TRUE;
-	aodata->data->interrupted = FALSE;
-	g_mutex_unlock (aodata->data->yes_or_no);
-
-	async_operation_step (aodata);
-}
-
-
- /**/
+/* load_images_preview */
 
 
 static void
@@ -635,12 +677,12 @@ load_images_preview__init (AsyncOperationData *aodata,
 static int
 get_default_icon_size (GtkWidget *widget)
 {
-        int icon_width, icon_height;
+	int icon_width, icon_height;
 
-        gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
-                                           GTK_ICON_SIZE_DIALOG,
-                                           &icon_width, &icon_height);
-        return MAX (icon_width, icon_height);
+	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
+					   GTK_ICON_SIZE_DIALOG,
+					   &icon_width, &icon_height);
+	return MAX (icon_width, icon_height);
 }
 
 
@@ -650,24 +692,24 @@ get_icon_from_mime_type (DialogData *data,
 {
 	GdkPixbuf      *pixbuf = NULL;
 	int             icon_size;
-        GtkIconTheme   *icon_theme = gtk_icon_theme_get_default ();
-        GtkIconInfo    *icon_info = NULL;
-        char           *icon_name;
+	GtkIconTheme   *icon_theme = gtk_icon_theme_get_default ();
+	GtkIconInfo    *icon_info = NULL;
+	char           *icon_name;
 
-        icon_size = get_default_icon_size (data->dialog);
-        icon_name = gnome_icon_lookup (icon_theme,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       mime_type,
-                                       GNOME_ICON_LOOKUP_FLAGS_NONE,
-                                       NULL);
+	icon_size = get_default_icon_size (data->dialog);
+	icon_name = gnome_icon_lookup (icon_theme,
+				       NULL,
+				       NULL,
+				       NULL,
+				       NULL,
+				       mime_type,
+				       GNOME_ICON_LOOKUP_FLAGS_NONE,
+				       NULL);
 	icon_info = gtk_icon_theme_lookup_icon (icon_theme,
-                                            icon_name,
-                                            icon_size,
-                                            0);
-        g_free (icon_name);
+					    icon_name,
+					    icon_size,
+					    0);
+	g_free (icon_name);
 
 	if (icon_info != NULL) {
 		pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
@@ -790,15 +832,15 @@ load_images_preview__done (AsyncOperationData *aodata,
 {
 	path_list_free (aodata->list);
 	task_terminated (data);
+	data->aodata = NULL;
 }
 
 
 static void
 load_images_preview (DialogData *data)
 {
-	GList              *file_list;
-	gboolean            error;
-	AsyncOperationData *aodata;
+	GList    *file_list;
+	gboolean  error;
 
 	gth_image_list_clear (GTH_IMAGE_LIST (data->image_list));
 
@@ -833,13 +875,13 @@ load_images_preview (DialogData *data)
 		gtk_window_set_resizable (GTK_WINDOW (data->dialog), TRUE);
 	}
 
-	aodata = async_operation_new (file_list,
-				      load_images_preview__init,
-				      load_images_preview__step,
-				      load_images_preview__done,
-				      data);
-
-	async_operation_start (aodata);
+	data->aodata = async_operation_new (NULL,
+					    file_list,
+					    load_images_preview__init,
+					    load_images_preview__step,
+					    load_images_preview__done,
+					    data);
+	async_operation_start (data->aodata);
 }
 
 
@@ -848,7 +890,7 @@ set_camera_model (DialogData *data,
 		  const char *model,
 		  const char *port)
 {
-        int r;
+	int r;
 
 	if ((model == NULL) || (port == NULL)) {
 		data->camera_setted = FALSE;
@@ -1211,7 +1253,7 @@ save_image (DialogData *data,
 			    GP_FILE_TYPE_NORMAL,
 			    file,
 			    data->context);
-	
+
 	unescaped_local_folder = gnome_vfs_unescape_string (local_folder, "");
 	file_uri = get_file_name (data, camera_path, unescaped_local_folder, n);
 	g_free (unescaped_local_folder);
@@ -1280,6 +1322,7 @@ delete_images__done (AsyncOperationData *aodata,
 	gboolean interrupted;
 
 	task_terminated (data);
+	data->aodata = NULL;
 
 	g_mutex_lock (data->yes_or_no);
 	interrupted = data->interrupted;
@@ -1290,13 +1333,13 @@ delete_images__done (AsyncOperationData *aodata,
 
 	data->view_folder = TRUE;
 
-        if (ImportPhotos) {
-                ImportPhotos = FALSE;
+	if (ImportPhotos) {
+		ImportPhotos = FALSE;
 		if (data->browser != NULL)
 			gtk_widget_show (GTK_WIDGET (data->browser));
-        }
+	}
 
-        gtk_widget_destroy (data->dialog);
+	gtk_widget_destroy (data->dialog);
 }
 
 
@@ -1324,8 +1367,9 @@ static void
 adjust_orientation__done (AsyncOperationData *aodata,
 			  DialogData         *data)
 {
-	gboolean            interrupted;
-	AsyncOperationData *new_aodata;
+	gboolean interrupted;
+
+	data->aodata = NULL;
 
 	g_mutex_lock (data->yes_or_no);
 	interrupted = data->interrupted;
@@ -1336,12 +1380,13 @@ adjust_orientation__done (AsyncOperationData *aodata,
 	if (interrupted)
 		return;
 
-	new_aodata = async_operation_new (data->delete_list,
-					  NULL,
-					  delete_images__step,
-					  delete_images__done,
-					  data);
-	async_operation_start (new_aodata);
+	data->aodata = async_operation_new (NULL,
+				  	    data->delete_list,
+					    NULL,
+					    delete_images__step,
+					    delete_images__done,
+					    data);
+	async_operation_start (data->aodata);
 }
 
 
@@ -1405,24 +1450,25 @@ static void
 save_images__done (AsyncOperationData *aodata,
 		   DialogData         *data)
 {
-	gboolean            interrupted;
-	gboolean            error;
-	AsyncOperationData *new_aodata;
+	gboolean interrupted;
+	gboolean error;
 
 	g_mutex_lock (data->yes_or_no);
 	interrupted = data->interrupted;
 	error = data->error;
 	g_mutex_unlock (data->yes_or_no);
 
+	data->aodata = NULL;
 	if (interrupted || error)
 		return;
 
-	new_aodata = async_operation_new (data->adjust_orientation_list,
-					  NULL,
-					  adjust_orientation__step,
-					  adjust_orientation__done,
-					  data);
-	async_operation_start (new_aodata);
+	data->aodata = async_operation_new (NULL,
+					    data->adjust_orientation_list,
+					    NULL,
+					    adjust_orientation__step,
+					    adjust_orientation__done,
+					    data);
+	async_operation_start (data->aodata);
 }
 
 
@@ -1449,11 +1495,10 @@ static void
 ok_clicked_cb (GtkButton  *button,
 	       DialogData *data)
 {
-	GList              *file_list = NULL, *scan;
-	GList              *sel_list;
-	gboolean            error;
-	AsyncOperationData *aodata;
-	GnomeVFSFileSize    total_size = 0;
+	GList            *file_list = NULL, *scan;
+	GList            *sel_list;
+	gboolean          error;
+	GnomeVFSFileSize  total_size = 0;
 
 	if (!data->camera_setted) {
 		display_error_dialog (data,
@@ -1575,12 +1620,13 @@ ok_clicked_cb (GtkButton  *button,
 
 	add_film_keyword (data->local_folder);
 
-	aodata = async_operation_new (file_list,
-				      save_images__init,
-				      save_images__step,
-				      save_images__done,
-				      data);
-	async_operation_start (aodata);
+	data->aodata = async_operation_new (NULL,
+					    file_list,
+					    save_images__init,
+					    save_images__step,
+					    save_images__done,
+					    data);
+	async_operation_start (data->aodata);
 }
 
 
@@ -1621,7 +1667,7 @@ choose_categories_cb (GtkButton  *button,
 
 static void
 reset_exif_tag_on_import_cb (GtkButton  *button,
-		                            DialogData *data)
+					    DialogData *data)
 {
 	eel_gconf_set_boolean (PREF_PHOTO_IMPORT_RESET_EXIF_ORIENTATION,
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->reset_exif_tag_on_import_checkbutton)));
@@ -1639,6 +1685,44 @@ import_reload_cb (GtkButton  *button,
 }
 
 
+/* delete_imported_images */
+
+
+static void
+delete_imported_images__init (AsyncOperationData *aodata,
+			      DialogData         *data)
+{
+}
+
+
+static void
+delete_imported_images__step (AsyncOperationData *aodata,
+			      DialogData         *data)
+{
+	const char *camera_path = aodata->scan->data;
+	char       *camera_folder;
+	const char *camera_filename;
+
+	camera_folder = remove_level_from_path (camera_path);
+	camera_filename = file_name_from_path (camera_path);
+
+	gp_camera_file_delete (data->camera, camera_folder, camera_filename, data->context);
+
+	g_free (camera_folder);
+}
+
+
+static void
+delete_imported_images__done (AsyncOperationData *aodata,
+			      DialogData         *data)
+{
+	path_list_free (aodata->list);
+	task_terminated (data);
+	data->aodata = NULL;
+	load_images_preview (data);
+}
+
+
 static void
 import_delete_cb (GtkButton  *button,
 		  DialogData *data)
@@ -1659,23 +1743,13 @@ import_delete_cb (GtkButton  *button,
 		file_data_list_free (sel_list);
 	}
 
-	for (scan = delete_list; scan; scan = scan->next) {
-		const char *camera_path = scan->data;
-		char       *camera_folder;
-		const char *camera_filename;
-
-		camera_folder = remove_level_from_path (camera_path);
-		camera_filename = file_name_from_path (camera_path);
-
-		gp_camera_file_delete (data->camera, camera_folder, camera_filename, data->context);
-		/* FIXME */
-	}
-
-	path_list_free (delete_list);
-
-	task_terminated (data);
-
-	load_images_preview (data);
+	data->aodata = async_operation_new (NULL,
+					    delete_list,
+					    delete_imported_images__init,
+					    delete_imported_images__step,
+					    delete_imported_images__done,
+					    data);
+	async_operation_start (data->aodata);
 }
 
 
@@ -1797,24 +1871,24 @@ dlg_photo_importer (GthBrowser *browser)
 	data->browser = browser;
 
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_FILE , NULL, NULL);
-        if (!data->gui) {
+	if (!data->gui) {
 		g_free (data);
-                g_warning ("Could not find " GLADE_FILE "\n");
-                return;
-        }
+		g_warning ("Could not find " GLADE_FILE "\n");
+		return;
+	}
 
 	gp_camera_new (&data->camera);
 	data->context = gp_context_new ();
 	gp_context_set_cancel_func (data->context, ctx_cancel_func, data);
-        gp_context_set_error_func (data->context, ctx_error_func, data);
-        gp_context_set_status_func (data->context, ctx_status_func, data);
-        gp_context_set_message_func (data->context, ctx_message_func, data);
+	gp_context_set_error_func (data->context, ctx_error_func, data);
+	gp_context_set_status_func (data->context, ctx_status_func, data);
+	gp_context_set_message_func (data->context, ctx_message_func, data);
 	gp_context_set_progress_funcs (data->context,
 				       ctx_progress_start_func,
 				       ctx_progress_update_func,
 				       ctx_progress_stop_func,
 				       data);
-        gp_abilities_list_new (&data->abilities_list);
+	gp_abilities_list_new (&data->abilities_list);
 	gp_port_info_list_new (&data->port_list);
 
 	data->categories_list = NULL;
@@ -1850,7 +1924,7 @@ dlg_photo_importer (GthBrowser *browser)
 	data->import_delete_button = glade_xml_get_widget (data->gui, "import_delete_button");
 	data->i_commands_table = glade_xml_get_widget (data->gui, "i_commands_table");
 	data->import_ok_button = glade_xml_get_widget (data->gui, "import_okbutton");
-        data->reset_exif_tag_on_import_checkbutton = glade_xml_get_widget (data->gui, "reset_exif_tag_on_import_checkbutton");
+	data->reset_exif_tag_on_import_checkbutton = glade_xml_get_widget (data->gui, "reset_exif_tag_on_import_checkbutton");
 	btn_cancel = glade_xml_get_widget (data->gui, "import_cancelbutton");
 	btn_help = glade_xml_get_widget (data->gui, "import_helpbutton");
 
@@ -2022,8 +2096,8 @@ get_camera_port_list (ModelDialogData *mdata, GPPortType types)
 	for (i = 0; i < n; i++) {
 		GPPortInfo info;
 		gp_port_info_list_get_info (mdata->data->port_list, i, &info);
-                if (info.type & types)
-                        list = g_list_prepend (list, g_strdup_printf ("%s", info.path));
+		if (info.type & types)
+			list = g_list_prepend (list, g_strdup_printf ("%s", info.path));
 	}
 
 	return g_list_reverse (list);
@@ -2114,7 +2188,7 @@ static void
 model__selection_changed_cb (GtkTreeSelection *selection,
 			     ModelDialogData  *mdata)
 {
-        GtkTreeIter     iter;
+	GtkTreeIter     iter;
 	GtkTreeModel    *treemodel;
 	gchar           *model;
 	GtkListStore    *store;
@@ -2123,8 +2197,8 @@ model__selection_changed_cb (GtkTreeSelection *selection,
 	GList           *list, *l;
 	gboolean        is_manual_selection;
 
-        if (gtk_tree_selection_get_selected (selection, &treemodel, &iter)) {
-                gtk_tree_model_get (treemodel, &iter, 0, &model, -1);
+	if (gtk_tree_selection_get_selected (selection, &treemodel, &iter)) {
+		gtk_tree_model_get (treemodel, &iter, 0, &model, -1);
 
 		store =  gtk_list_store_new (1, G_TYPE_STRING);
 		is_manual_selection = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(mdata->cm_manual_selection_checkbutton));
@@ -2151,8 +2225,8 @@ model__selection_changed_cb (GtkTreeSelection *selection,
  		gtk_combo_box_set_active (GTK_COMBO_BOX (mdata->cm_port_combo_box), 0);
 
 		g_object_unref (store);
-                g_free (model);
-        }
+		g_free (model);
+	}
 }
 
 
@@ -2231,11 +2305,11 @@ dlg_select_camera_model_cb (GtkButton  *button,
 	mdata->data = data;
 
 	mdata->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_FILE , NULL, NULL);
-        if (!mdata->gui) {
+	if (!mdata->gui) {
 		g_free (mdata);
-                g_warning ("Could not find " GLADE_FILE "\n");
-                return;
-        }
+		g_warning ("Could not find " GLADE_FILE "\n");
+		return;
+	}
 
 	/* Get the widgets. */
 
@@ -2270,10 +2344,10 @@ dlg_select_camera_model_cb (GtkButton  *button,
 			  "clicked",
 			  G_CALLBACK (model__ok_clicked_cb),
 			  mdata);
-        g_signal_connect (G_OBJECT (btn_help),
-                          "clicked",
-                          G_CALLBACK (help_cb),
-                          mdata);
+	g_signal_connect (G_OBJECT (btn_help),
+			  "clicked",
+			  G_CALLBACK (help_cb),
+			  mdata);
 	g_signal_connect_swapped (G_OBJECT (btn_cancel),
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
