@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003, 2005 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include <glade/glade.h>
 
 #include "async-pixbuf-ops.h"
-#include "gthumb-window.h"
+#include "gth-window.h"
 #include "gthumb-stock.h"
 #include "pixbuf-utils.h"
 
@@ -42,7 +42,7 @@
 
 
 typedef struct {
-	GThumbWindow *window;
+	GthWindow    *window;
 	ImageViewer  *viewer;
 	GdkPixbuf    *image;
 	GdkPixbuf    *orig_pixbuf;
@@ -61,7 +61,7 @@ typedef struct {
 
 /* called when the main dialog is closed. */
 static void
-destroy_cb (GtkWidget  *widget, 
+destroy_cb (GtkWidget  *widget,
 	    DialogData *data)
 {
 	g_object_unref (data->image);
@@ -84,25 +84,26 @@ preview_done_cb (GthPixbufOp *pixop,
 
 
 static void
-apply_changes (DialogData *data, 
+apply_changes (DialogData *data,
 	       GdkPixbuf  *src, 
 	       GdkPixbuf  *dest, 
-	       gboolean    preview)
+	       gboolean    dialog_preview,
+	       gboolean    window_preview)
 {
 	int          levels;
 	GthPixbufOp *pixop;
-	
+
 	levels = (int) gtk_range_get_value (GTK_RANGE (data->p_levels_hscale));
 	pixop = _gdk_pixbuf_posterize (src, dest, levels);
 
-	if (preview) {
+	if (dialog_preview) {
 		g_signal_connect (G_OBJECT (pixop),
 				  "pixbuf_op_done",
 				  G_CALLBACK (preview_done_cb),
 				  data);
 		gth_pixbuf_op_start (pixop);
 	} else {
-		window_exec_pixbuf_op (data->window, pixop);
+		gth_window_exec_pixbuf_op (data->window, pixop, window_preview);
 		g_object_unref (pixop);
 	}
 }
@@ -110,24 +111,22 @@ apply_changes (DialogData *data,
 
 /* called when the ok button is clicked. */
 static void
-ok_cb (GtkWidget  *widget, 
+ok_cb (GtkWidget  *widget,
        DialogData *data)
 {
-	apply_changes (data, data->image, data->image, FALSE);
-	image_viewer_set_pixbuf (data->viewer, data->image);
-	window_image_set_modified (data->window, TRUE);
+	apply_changes (data, data->image, data->image, FALSE, FALSE);
 	gtk_widget_destroy (data->dialog);
 }
 
 
 /* called when the cancel button is clicked. */
 static void
-cancel_cb (GtkWidget  *widget, 
+cancel_cb (GtkWidget  *widget,
 	   DialogData *data)
 {
 	if (data->modified) {
 		image_viewer_set_pixbuf (data->viewer, data->image);
-		window_image_set_modified (data->window, data->original_modified);
+		gth_window_set_image_modified (data->window, data->original_modified);
 	}
 	gtk_widget_destroy (data->dialog);
 }
@@ -135,13 +134,13 @@ cancel_cb (GtkWidget  *widget,
 
 /* called when the preview button is clicked. */
 static void
-preview_cb (GtkWidget  *widget, 
+preview_cb (GtkWidget  *widget,
 	    DialogData *data)
 {
 	GdkPixbuf *preview;
 
 	preview = gdk_pixbuf_copy (data->image);
-	apply_changes (data, preview, preview, FALSE);
+	apply_changes (data, preview, preview, FALSE, TRUE);
 	g_object_unref (preview);
 
 	data->modified = TRUE;
@@ -150,7 +149,7 @@ preview_cb (GtkWidget  *widget,
 
 /* called when the revert button is clicked. */
 static void
-reset_cb (GtkWidget  *widget, 
+reset_cb (GtkWidget  *widget,
 	  DialogData *data)
 {
 	gtk_range_set_value (GTK_RANGE (data->p_levels_hscale), DEFAULT_VALUE);
@@ -161,17 +160,17 @@ static void
 range_value_changed (GtkRange   *range,
 		     DialogData *data)
 {
-	apply_changes (data, data->orig_pixbuf, data->new_pixbuf, TRUE);
+	apply_changes (data, data->orig_pixbuf, data->new_pixbuf, TRUE, FALSE);
 }
 
 
 static GtkWidget*
 gimp_scale_entry_new (GtkWidget  *parent_box,
 		      gfloat      value,
-                      gfloat      lower,
-                      gfloat      upper,
-                      gfloat      step_increment,
-                      gfloat      page_increment)
+		      gfloat      lower,
+		      gfloat      upper,
+		      gfloat      step_increment,
+		      gfloat      page_increment)
 {
 	GtkWidget *hbox;
 	GtkWidget *scale;
@@ -181,7 +180,7 @@ gimp_scale_entry_new (GtkWidget  *parent_box,
 	adj = gtk_adjustment_new (value, lower, upper,
 				  step_increment, page_increment,
 				  0.0);
-	
+
 	spinbutton = gtk_spin_button_new  (GTK_ADJUSTMENT (adj), 1.0, 0);
 	scale = gtk_hscale_new (GTK_ADJUSTMENT (adj));
 	gtk_scale_set_draw_value (GTK_SCALE (scale), FALSE);
@@ -200,7 +199,7 @@ gimp_scale_entry_new (GtkWidget  *parent_box,
 
 
 void
-dlg_posterize (GThumbWindow *window)
+dlg_posterize (GthWindow *window)
 {
 	DialogData *data;
 	GtkWidget  *ok_button;
@@ -215,7 +214,7 @@ dlg_posterize (GThumbWindow *window)
 
 	data = g_new0 (DialogData, 1);
 	data->window = window;
-	data->original_modified = window_image_get_modified (window);
+	data->original_modified = gth_window_get_image_modified (window);
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_FILE, NULL,
 				   NULL);
 
@@ -236,13 +235,13 @@ dlg_posterize (GThumbWindow *window)
 	preview_button = glade_xml_get_widget (data->gui, "p_preview_button");
 
 	hbox = glade_xml_get_widget (data->gui, "p_levels_hbox");
-	data->p_levels_hscale = gimp_scale_entry_new (hbox, 
+	data->p_levels_hscale = gimp_scale_entry_new (hbox,
 						      DEFAULT_VALUE, 
 						      2.0, 256.0,
 						      1.0,
 						      10.0);
 
-	data->viewer = IMAGE_VIEWER (window->viewer);
+	data->viewer = gth_window_get_image_viewer (window);
 
 	reset_image = glade_xml_get_widget (data->gui, "p_reset_image");
 	gtk_image_set_from_stock (GTK_IMAGE (reset_image), GTHUMB_STOCK_RESET, GTK_ICON_SIZE_MENU);
@@ -258,41 +257,41 @@ dlg_posterize (GThumbWindow *window)
 	preview_width  = image_width;
 	preview_height = image_height;
 	scale_keepping_ratio (&preview_width, &preview_height, PREVIEW_SIZE, PREVIEW_SIZE);
-	
-	data->orig_pixbuf = gdk_pixbuf_scale_simple (image, 
+
+	data->orig_pixbuf = gdk_pixbuf_scale_simple (image,
 						     preview_width, 
 						     preview_height,
 						     GDK_INTERP_BILINEAR);
 	data->new_pixbuf = gdk_pixbuf_copy (data->orig_pixbuf);
 
-	gtk_image_set_from_pixbuf (GTK_IMAGE (data->p_preview_image), 
+	gtk_image_set_from_pixbuf (GTK_IMAGE (data->p_preview_image),
 				   data->new_pixbuf);
-	
+
 	/* Set widgets data. */
 
 	/* Set the signals handlers. */
-	
+
 	g_signal_connect (G_OBJECT (data->dialog),
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (cancel_button), 
+	g_signal_connect (G_OBJECT (cancel_button),
 			  "clicked",
 			  G_CALLBACK (cancel_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (ok_button), 
+	g_signal_connect (G_OBJECT (ok_button),
 			  "clicked",
 			  G_CALLBACK (ok_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (reset_button), 
+	g_signal_connect (G_OBJECT (reset_button),
 			  "clicked",
 			  G_CALLBACK (reset_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (preview_button), 
+	g_signal_connect (G_OBJECT (preview_button),
 			  "clicked",
 			  G_CALLBACK (preview_cb),
 			  data);
@@ -307,8 +306,9 @@ dlg_posterize (GThumbWindow *window)
 	/* Run dialog. */
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
-				      GTK_WINDOW (window->app));
+				      GTK_WINDOW (window));
+	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE);
 	gtk_widget_show (data->dialog);
 
-	apply_changes (data, data->orig_pixbuf, data->new_pixbuf, TRUE);
+	apply_changes (data, data->orig_pixbuf, data->new_pixbuf, TRUE, FALSE);
 }
