@@ -173,7 +173,7 @@ remove_folder_comment_cb (gpointer key, gpointer value, gpointer user_data)
 {
 	g_free (key);
 	comment_data_free (value);
-        return TRUE;
+	return TRUE;
 }
 
 
@@ -344,16 +344,17 @@ static void
 view_result_cb (GtkWidget  *widget,
 		DialogData *data)
 {
-	Catalog      *catalog;
-	char         *catalog_name, *catalog_path, *catalog_name_utf8;
-	GList        *scan;
-	GError       *gerror;
+	Catalog *catalog;
+	char    *catalog_name, *catalog_path, *catalog_name_utf8;
+	GList   *scan;
+	GError  *gerror;
 
 	if (data->files == NULL)
 		return;
 
-	catalog = catalog_new ();
+	cancel_progress_dlg_cb (widget, data);
 
+	catalog = catalog_new ();
 	catalog_name_utf8 = g_strconcat (_("Search Result"),
 					 CATALOG_EXT,
 					 NULL);
@@ -373,9 +374,10 @@ view_result_cb (GtkWidget  *widget,
 
 	gth_browser_go_to_catalog (data->browser, catalog_path);
 
-	gtk_widget_destroy (data->search_progress_dialog);
 	catalog_free (catalog);
 	g_free (catalog_path);
+
+	gtk_widget_destroy (data->search_progress_dialog);
 }
 
 
@@ -441,6 +443,7 @@ static void
 cancel_progress_dlg_cb (GtkWidget  *widget,
 			DialogData *data)
 {
+	gth_file_list_stop (data->file_list);
 	if (data->handle == NULL)
 		return;
 	gnome_vfs_async_cancel (data->handle);
@@ -708,6 +711,7 @@ pattern_matched_by_keywords (char  *pattern,
 	GPatternSpec *spec;
 	gboolean      retval = FALSE;
 	int           i;
+	char	     *norm_pattern;
 
 	if (pattern == NULL)
 		return TRUE;
@@ -715,14 +719,26 @@ pattern_matched_by_keywords (char  *pattern,
 	if ((keywords == NULL) || (keywords[0] == NULL))
 		return FALSE;
 
-	spec = g_pattern_spec_new (pattern);
+	norm_pattern = g_utf8_normalize (pattern,
+	                                 -1,
+	                                 G_NORMALIZE_NFC);
+	spec = g_pattern_spec_new (norm_pattern);
+	g_free (norm_pattern);
+
 	for (i = 0; keywords[i] != NULL; i++) {
 		char     *case_string;
+		char     *norm_string;
 		gboolean  match;
 
 		case_string = g_utf8_casefold (keywords[i], -1);
-		match = g_pattern_match_string (spec, case_string);
+		norm_string = g_utf8_normalize (case_string,
+		                                -1,
+		                                G_NORMALIZE_NFC);
+
+		match = g_pattern_match_string (spec, norm_string);
+
 		g_free (case_string);
+		g_free (norm_string);
 
 		if (match) {
 			retval = TRUE;
@@ -740,6 +756,7 @@ match_patterns (char       **patterns,
 		const char  *string)
 {
 	char     *case_string;
+	char     *norm_string;
 	int       i;
 	gboolean  retval = FALSE;
 
@@ -750,13 +767,29 @@ match_patterns (char       **patterns,
 		return FALSE;
 
 	case_string = g_utf8_casefold (string, -1);
+	norm_string = g_utf8_normalize (case_string,
+	                                -1,
+	                                G_NORMALIZE_NFC);
+
 	for (i = 0; patterns[i] != NULL; i++) {
-		if (g_pattern_match_simple (patterns[i], case_string)) {
+		gboolean  match;
+		char     *norm_pattern;
+
+		norm_pattern = g_utf8_normalize (patterns[i],
+                                                 -1,
+	                                         G_NORMALIZE_NFC);
+
+		match = g_pattern_match_simple (norm_pattern, norm_string);
+
+		g_free (norm_pattern);
+
+		if (match) {
 			retval = TRUE;
 			break;
 		}
 	}
 	g_free (case_string);
+	g_free (norm_string);
 
 	return retval;
 }
@@ -959,6 +992,7 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 	for (node = list; node != NULL; node = node->next) {
 		GnomeVFSURI *full_uri = NULL;
 		char        *str_uri;
+		char	    *unesc_uri;
 
 		info = node->data;
 
@@ -968,10 +1002,14 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 				break;
 			full_uri = gnome_vfs_uri_append_file_name (data->uri, info->name);
 			str_uri = gnome_vfs_uri_to_string (full_uri, GNOME_VFS_URI_HIDE_NONE);
-			if (file_respects_search_criteria (data, str_uri))
+			unesc_uri = gnome_vfs_unescape_string (str_uri, "");
+
+			if (file_respects_search_criteria (data, unesc_uri))
 				files = g_list_prepend (files, str_uri);
 			else
 				g_free (str_uri);
+
+			g_free (unesc_uri);
 			break;
 
 		case GNOME_VFS_FILE_TYPE_DIRECTORY:
