@@ -56,7 +56,7 @@
 #define X_PADDING  12
 #define Y_PADDING  6
 #define MOTION_THRESHOLD 3
-#define DEF_SLIDESHOW_DELAY 4
+#define DEF_SLIDESHOW_DELAY 4.0
 #define SECONDS 1000
 
 
@@ -74,6 +74,7 @@ struct _GthFullscreenPrivateData {
 	GthDirectionType slideshow_direction;
 	int              slideshow_delay;
 	gboolean         slideshow_wrap_around;
+	gboolean         fading_activated;
 	guint            slideshow_timeout;
 	guint            slideshow_paused;
 
@@ -134,7 +135,8 @@ gth_fullscreen_finalize (GObject *object)
 
 		g_object_unref (priv->screensaver);
 
-		gs_fade_reset (priv->fade);
+		if (priv->fading_activated)
+			gs_fade_reset (priv->fade);
 		g_object_unref (priv->fade);
 
 		g_free (priv->image_path);
@@ -206,12 +208,14 @@ viewer_image_loaded_cb (ImageViewer   *iviewer,
 {
 	GthFullscreenPrivateData *priv = fullscreen->priv;
 
-	if (priv->use_fade) {
-		gs_fade_in (priv->fade);
-		return;
+	if (priv->fading_activated) {
+		if (priv->use_fade) {
+			gs_fade_in (priv->fade);
+			return;
+		}
+		gs_fade_reset (priv->fade);
 	}
 
-	gs_fade_reset (priv->fade);
 	if (priv->slideshow)
 		continue_slideshow (fullscreen);
 }
@@ -549,12 +553,14 @@ load_current_image (GthFullscreen *fullscreen)
 {
 	GthFullscreenPrivateData *priv = fullscreen->priv;
 
-	if (priv->use_fade) {
-		gs_fade_out (fullscreen->priv->fade);
-		return;
+	if (priv->fading_activated) {
+		if (priv->use_fade) {
+			gs_fade_out (fullscreen->priv->fade);
+			return;
+		}
+		gs_fade_reset (fullscreen->priv->fade);
 	}
 
-	gs_fade_reset (fullscreen->priv->fade);
 	real_load_current_image (fullscreen);
 }
 
@@ -766,7 +772,7 @@ escape_filename (const char *text)
 	char *utf8_text;
 	char *escaped_text;
 
-	utf8_text = g_filename_display_name (text);
+	utf8_text = gnome_vfs_unescape_string_for_display (text);
 	escaped_text = g_markup_escape_text (utf8_text, -1);
 	g_free (utf8_text);
 
@@ -1098,7 +1104,6 @@ viewer_key_press_cb (GtkWidget   *widget,
 	GthFullscreen *fullscreen = data;
 	GthFullscreenPrivateData *priv = fullscreen->priv;
 	GthWindow     *window = (GthWindow*) fullscreen;
-	ImageViewer   *viewer = (ImageViewer*) fullscreen->priv->viewer;
 	gboolean       retval = TRUE;
 	GtkAction     *a;
 
@@ -1136,36 +1141,6 @@ viewer_key_press_cb (GtkWidget   *widget,
 			retval = FALSE;
 		break;
 
-		/* Zoom in. */
-	case GDK_plus:
-	case GDK_equal:
-	case GDK_KP_Add:
-		image_viewer_zoom_in (viewer);
-		break;
-
-		/* Zoom out. */
-	case GDK_minus:
-	case GDK_KP_Subtract:
-		image_viewer_zoom_out (viewer);
-		break;
-
-		/* Actual size. */
-	case GDK_KP_Divide:
-	case GDK_1:
-	case GDK_z:
-		image_viewer_set_zoom (viewer, 1.0);
-		break;
-
-		/* Set zoom to 2.0. */
-	case GDK_2:
-		image_viewer_set_zoom (viewer, 2.0);
-		break;
-
-		/* Set zoom to 3.0. */
-	case GDK_3:
-		image_viewer_set_zoom (viewer, 3.0);
-		break;
-
 		/* Toggle animation. */
 	case GDK_a:
 		gth_window_set_animation (window, ! gth_window_get_animation (window));
@@ -1233,18 +1208,6 @@ viewer_key_press_cb (GtkWidget   *widget,
 		}
 		break;
 
-		/* Zoom to fit */
-	case GDK_x:
-		gth_window_activate_action_view_zoom_fit (NULL, window);
-		retval = TRUE;
-		break;
-
-		/* Zoom to fit width */
-	case GDK_w:
-		gth_window_activate_action_view_zoom_to_width (NULL, window);
-		retval = TRUE;
-		break;
-
 		/* Rotate clockwise without saving */
 	case GDK_r:
 		gth_window_activate_action_alter_image_rotate90 (NULL, window);
@@ -1404,6 +1367,28 @@ delete_list_from_file_list (GthFullscreen *fullscreen,
 }
 
 
+static void
+monitor_update_cat_files_cb (GthMonitor      *monitor,
+			     const char      *catalog_name,
+			     GthMonitorEvent  event,
+			     GList           *list,
+			     GthFullscreen   *fullscreen)
+{
+	if (fullscreen->priv->catalog_path == NULL)
+		return;
+	if (! same_uri (fullscreen->priv->catalog_path, catalog_name))
+		return;
+
+	switch (event) {
+	case GTH_MONITOR_EVENT_DELETED:
+		delete_list_from_file_list (fullscreen, list);
+		break;
+	default:
+		break;
+	}
+}
+
+
 static void
 monitor_update_files_cb (GthMonitor      *monitor,
 			 GthMonitorEvent  event,
@@ -1572,6 +1557,10 @@ gth_fullscreen_construct (GthFullscreen *fullscreen,
 			  "update_files",
 			  G_CALLBACK (monitor_update_files_cb),
 			  fullscreen);
+	g_signal_connect (G_OBJECT (monitor),
+			  "update_cat_files",
+			  G_CALLBACK (monitor_update_cat_files_cb),
+			  fullscreen);
 	g_signal_connect (G_OBJECT (monitor),
 			  "update_metadata",
 			  G_CALLBACK (monitor_update_metadata_cb),
@@ -1675,8 +1664,9 @@ gth_fullscreen_show (GtkWidget *widget)
 	create_toolbar_window (fullscreen);
 
 	priv->slideshow_direction = pref_get_slideshow_direction ();
-	priv->slideshow_delay = eel_gconf_get_integer (PREF_SLIDESHOW_DELAY, DEF_SLIDESHOW_DELAY);
+	priv->slideshow_delay = eel_gconf_get_float (PREF_SLIDESHOW_DELAY, DEF_SLIDESHOW_DELAY);
 	priv->slideshow_wrap_around = eel_gconf_get_boolean (PREF_SLIDESHOW_WRAP_AROUND, FALSE);
+	priv->fading_activated = eel_gconf_get_boolean (PREF_SLIDESHOW_FADING, TRUE);
 
 	image_viewer_hide_cursor (IMAGE_VIEWER (priv->viewer));
 	gtk_window_fullscreen (GTK_WINDOW (widget));
@@ -1852,7 +1842,6 @@ gth_fullscreen_set_catalog (GthFullscreen *fullscreen,
 
 	g_free (fullscreen->priv->catalog_path);
 	fullscreen->priv->catalog_path = NULL;
-
 	if (catalog_path != NULL)
 		fullscreen->priv->catalog_path = g_strdup (catalog_path);
 }
