@@ -27,6 +27,7 @@
 #include "gth-window.h"
 #include "dlg-comment.h"
 #include "dlg-categories.h"
+#include "main.h"
 
 enum {
         PROP_0,
@@ -59,9 +60,10 @@ gth_window_finalize (GObject *object)
 		window->priv = NULL;
 	}
 
+	window_list = g_list_remove (window_list, window);
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
-	window_list = g_list_remove (window_list, window);
 	if (window_list == NULL)
 		gtk_main_quit ();
 }
@@ -236,6 +238,9 @@ gth_window_init (GthWindow *window)
 	priv->history = gth_image_history_new ();
 
 	window_list = g_list_prepend (window_list, window);
+#ifdef HAVE_GTKUNIQUE
+	gtk_unique_app_add_window (gth_application, GTK_WINDOW (window));
+#endif /* HAVE_GTKUNIQUE */
 }
 
 
@@ -283,6 +288,10 @@ gth_window_close (GthWindow *window)
 		priv->categories_dlg = NULL;
 	}
 
+#ifdef HAVE_GTKUNIQUE
+	gtk_unique_app_remove_window (gth_application, GTK_WINDOW (window));
+#endif /* HAVE_GTKUNIQUE */
+
 	class->close (window);
 }
 
@@ -439,33 +448,33 @@ gth_window_attach (GthWindow     *window,
 		   GtkWidget     *child,
 		   GthWindowArea  area)
 {
-	gint position;
+	int position;
+
 	g_return_if_fail (window != NULL);
 	g_return_if_fail (GTH_IS_WINDOW (window));
 	g_return_if_fail (child != NULL);
 	g_return_if_fail (GTK_IS_WIDGET (child));
 
-	switch(area)
-	{
-		case GTH_WINDOW_MENUBAR:
-			position = 0;
-			break;
-		case GTH_WINDOW_TOOLBAR:
-			position = 1;
-			break;
-		case GTH_WINDOW_CONTENTS:
-			position = 2;
-			if(window->priv->contents != NULL)
-				gtk_widget_destroy (window->priv->contents);
-			window->priv->contents = child;
-			break;
-		case GTH_WINDOW_STATUSBAR:
-			position = 3;
-			break;
-		default:
-			g_critical("%s: area not recognized!", G_STRFUNC);
-			return;
-			break;
+	switch (area) {
+	case GTH_WINDOW_MENUBAR:
+		position = 0;
+		break;
+	case GTH_WINDOW_TOOLBAR:
+		position = 1;
+		break;
+	case GTH_WINDOW_CONTENTS:
+		position = 2;
+		if (window->priv->contents != NULL)
+			gtk_widget_destroy (window->priv->contents);
+		window->priv->contents = child;
+		break;
+	case GTH_WINDOW_STATUSBAR:
+		position = 3;
+		break;
+	default:
+		g_critical("%s: area not recognized!", G_STRFUNC);
+		return;
+		break;
 	}
 
 	gtk_table_attach (GTK_TABLE (window->priv->table),
