@@ -83,9 +83,6 @@ loader_error_cb (ImageLoader  *il,
 		timeout = NEXT_LOAD_BIG_TIMEOUT;
 	}
 
-	/*
-	gploader->load_id = g_timeout_add (timeout, load_next, gploader);
-	*/
 	gploader->load_id = g_idle_add (load_next, gploader);
 }
 
@@ -139,10 +136,10 @@ preloader_new (GThumbPreloader *gploader)
 static void
 preloader_free (PreLoader *ploader)
 {
-	g_return_if_fail (ploader != NULL);
-
-	g_free (ploader->path);
+	if (ploader == NULL)
+		return;
 	g_object_unref (ploader->loader);
+	g_free (ploader->path);
 	g_free (ploader);
 }
 
@@ -168,28 +165,14 @@ preloader_set_path (PreLoader  *ploader,
 }
 
 
-
 /* -- GThumbPreloader -- */
 
 
-void
-gploader_finalize__step2 (GObject *object)
-{
-	GThumbPreloader *gploader = GTHUMB_PRELOADER (object);
-	int              i;
-
-	for (i = 0; i < N_LOADERS; i++)
-		preloader_free (gploader->loader[i]);
-
-	/* Chain up */
-	G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
-
 static void
 gthumb_preloader_finalize (GObject *object)
 {
 	GThumbPreloader *gploader;
+	int              i;
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GTHUMB_IS_PRELOADER (object));
@@ -201,7 +184,13 @@ gthumb_preloader_finalize (GObject *object)
 		gploader->load_id = 0;
 	}
 
-	gthumb_preloader_stop (gploader, (DoneFunc) gploader_finalize__step2, object);
+	for (i = 0; i < N_LOADERS; i++) {
+		preloader_free (gploader->loader[i]);
+		gploader->loader[i] = NULL;
+	}
+
+	/* Chain up */
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 
